FigShellContext class

Context about the current shell session. Aligns with Fig.ShellContext.

Implementers

Constructors

FigShellContext({required String currentWorkingDirectory, String currentProcess = '', String sshPrefix = ''})
const

Properties

currentProcess String
final
currentWorkingDirectory String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sshPrefix String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited