collectionDownloadOptions top-level property

List<Option> collectionDownloadOptions
final

Implementation

final List<Option> collectionDownloadOptions = [

  Option(
    name: '--clear-response-cache',
    description: 'Clear the existing server response cache'
  ),
  Option(
    name: '--no-cache',
    description: 'Do not use the server response cache'
  ),
  Option(
    name: ['--no-deps', '-n'],
    description: 'Don\'t download collection(s) listed as dependencies'
  ),
  Option(
    name: ['--download-path', '-p'],
    description: 'The directory to download the collections to',
    args: [
      Arg(
      name: 'download_path',
      description: 'The directory to download the collections to',
      template: ['folders']
    )
    ]
  ),
  Option(
    name: ['--requirements-file', '-r'],
    description: 'A file containing a list of collections to be downloaded',
    args: [
      Arg(
      name: 'requirements',
      description: 'A file containing a list of collections to be downloaded',
      template: ['filepaths']
    )
    ]
  ),
  Option(
    name: '--pre',
    description: 'Include pre-release versions'
  )
];