collectionInitOptions top-level property

List<Option> collectionInitOptions
final

Implementation

final List<Option> collectionInitOptions = [

  Option(
    name: ['--force', '-f'],
    description: 'Force overwriting an existing role or collection'
  ),
  Option(
    name: '--init-path',
    description: 'The path in which the skeleton collection will be created',
    args: [
      Arg(
      name: 'init_path',
      description: 'The path in which the skeleton collection will be created',
      template: ['folders'],
      defaultValue: '.'
    )
    ]
  ),
  Option(
    name: '--collection-skeleton',
    description: 'The path to a collection skeleton that the new collection should be based upon',
    args: [
      Arg(
      name: 'collection_skeleton',
      description: 'The path to a collection skeleton that the new collection should be based upon',
      template: ['folders']
    )
    ]
  )
];