collectionVerifyOptions top-level property

List<Option> collectionVerifyOptions
final

Implementation

final List<Option> collectionVerifyOptions = [

  Option(
    name: ['--collections-path', '-p'],
    description: 'One or more directories to search for collections in addition to the default COLLECTIONS_PATHS; separate multiple paths with \':\'',
    args: [
      Arg(
      name: 'collections_path',
      description: 'One or more directories to search for collections in addition to the default COLLECTIONS_PATHS; separate multiple paths with \':\'',
      template: ['folders'],
      suggestions: [

        FigSuggestion(name: '~/.ansible/collections:/usr/share/ansible/collections')
      ],
      defaultValue: '~/.ansible/collections:/usr/share/ansible/collections'
    )
    ]
  ),
  Option(
    name: ['--ignore-errors', '-i'],
    description: 'Ignore errors during verification and continue with the next specified collection'
  ),
  Option(
    name: ['--requirements-file', '-r'],
    description: 'A file containing a list of collections to be downloaded',
    args: [
      Arg(
      name: 'requirements',
      description: 'A file containing a list of collections to be downloaded',
      template: ['filepaths']
    )
    ]
  )
];