roleImportOptions top-level property

List<Option> roleImportOptions
final

Implementation

final List<Option> roleImportOptions = [

  Option(
    name: '--branch',
    description: 'The name of a branch to import. Defaults to the repository\'s default branch (usually master)',
    args: [
      Arg(
      name: 'reference',
      description: 'The name of a branch to import. Defaults to the repository\'s default branch (usually master)',
      suggestions: [

        FigSuggestion(name: 'master'),
        FigSuggestion(name: 'main'),
        FigSuggestion(name: 'develop')
      ],
      defaultValue: 'master'
    )
    ]
  ),
  Option(
    name: '--role-name',
    description: 'The name the role should have, if different than the repo name',
    args: [
      Arg(
      name: 'role_name',
      description: 'The name the role should have, if different than the repo name'
    )
    ]
  ),
  Option(
    name: '--status',
    description: 'Check the status of the most recent import request for given github_user/github_repo'
  )
];