roleInitOptions top-level property

List<Option> roleInitOptions
final

Implementation

final List<Option> roleInitOptions = [

  Option(
    name: ['--force', '-f'],
    description: 'Force overwriting an existing role or collection'
  ),
  Option(
    name: '--offline',
    description: 'Don\'t query the galaxy API when creating roles'
  ),
  Option(
    name: '--init-path',
    description: 'The path in which the skeleton collection will be created',
    args: [
      Arg(
      name: 'init_path',
      description: 'The path in which the skeleton collection will be created',
      template: ['folders'],
      defaultValue: '.'
    )
    ]
  ),
  Option(
    name: '--role-skeleton',
    description: 'The path in which the skeleton role will be created',
    args: [
      Arg(
      name: 'role_skeleton',
      description: 'The path in which the skeleton role will be created',
      template: ['folders'],
      defaultValue: '.'
    )
    ]
  ),
  Option(
    name: '--type',
    description: 'Initialize using an alternate role type',
    args: [
      Arg(
      name: 'role_type',
      description: 'Initialize using an alternate role type',
      suggestions: [

        FigSuggestion(name: 'container'),
        FigSuggestion(name: 'apb'),
        FigSuggestion(name: 'network')
      ],
      defaultValue: 'container'
    )
    ]
  )
];