globalOptions top-level property

List<Option> globalOptions
getter/setter pair

Implementation

List<Option> globalOptions = [
  Option(
    name: '--argo-base-href',
    description: 'An path to use with HTTP client (e.g. due to BASE_HREF). '
        'Defaults to the ARGO_BASE_HREF environment variable',
    args: Arg(name: 'string'),
  ),
  Option(
    name: '--argo-http1',
    description: 'If True, Use the HTTP client. '
        'Defaults to the ARGO_HTTP1 environment variable',
  ),
  Option(
    name: ['--argo-server', '-s'],
    description: 'API server host:port. e.g. localhost:2746. '
        'Defaults to the ARGO_SERVER environment variable',
    args: Arg(name: 'host:port'),
  ),
  Option(
    name: '--as',
    description: 'Username to impersonate for the operation',
    args: Arg(name: 'string'),
  ),
  Option(
    name: '--as-group',
    description: 'Group to impersonate for the operation, '
        'This flag can be repeated to specify multiple groups',
    args: Arg(name: 'stringArray'),
  ),
  Option(
    name: '--as-uid',
    description: 'UID to impersonate for the operation',
    args: Arg(name: 'string'),
  ),
  Option(
    name: '--certificate-authorityk',
    description: 'Path to a cert file for the certificate authority',
    args: Arg(name: 'string'),
  ),
  Option(
    name: '--client-certificate',
    description: 'Path to a client certificate file for TLS',
    args: Arg(name: 'string'),
  ),
  Option(
    name: '--client-key',
    description: 'Path to a client key file for TLS',
    args: Arg(name: 'string'),
  ),
  Option(
    name: '--cluster',
    description: 'The name of the kubeconfig cluster to use',
    args: Arg(name: 'string'),
  ),
  Option(
    name: '--context',
    description: 'The name of the kubeconfig context to use',
    args: Arg(name: 'string'),
  ),
  Option(
    name: '--gloglevel',
    description: 'Set the glog logging level',
    args: Arg(name: 'int'),
  ),
  Option(
    name: ['--header', '-H'],
    description: 'Sets additional header to all requests made by Argo CLI. '
        '(Can be repeated multiple times to add multiple headers',
    args: Arg(name: 'int'),
  ),
  Option(
    name: ['--help', '-h'],
    description: 'Help for argo',
  ),
  Option(
    name: '--insecure-skip-tls-verify',
    description:
        'If True, The server\'s certificate will not be checked for validity. '
        'This will make your HTTPS connections insecure',
  ),
  Option(
    name: ['--insecure-skip-verify', '-k'],
    description:
        'If true the Argo Server\'s certificate will not be checked for validity. '
        'This will make your HTTPS connections insecure. '
        'Defaults to the ARGO_INSECURE_SKIP_VERIFY environment variable',
  ),
  Option(
    name: '--instanceid',
    description: 'Submit with a specific controller\'s instance id label. '
        'Default to the ARGO_INSTANCEID environment variable',
    args: Arg(name: 'string'),
  ),
  Option(
    name: '--kubeconfig',
    description: 'Path to a kube config. Only required if out-of-cluster',
    args: Arg(name: 'string'),
  ),
  Option(
    name: '--loglevel',
    description:
        'Set the logging level. One of: debug|info|warn|error (default "info")',
    args: Arg(name: 'string'),
  ),
  Option(
    name: ['--namespace', '-n'],
    description: 'If present the namespace scope for this CLI request',
    args: Arg(name: 'string'),
  ),
  Option(
    name: '--password',
    description: 'Password for basic authentication to the API server',
    args: Arg(name: 'string'),
  ),
  Option(
    name: '--proxy-url',
    description: 'This URL will be used to connect via proxy',
    args: Arg(name: 'string'),
  ),
  Option(
    name: '--request-timeout',
    description:
        'The length of time to wait before giving up on a single server request. '
        'Non-zero values should contain a corresponding time unit (e.g. 1s, 2m)',
    args: Arg(name: 'string'),
  ),
  Option(
    name: ['--secure', '-e'],
    description: 'Whether or not the server is using TLS with the Argo Server. '
        'Defaults to the ARGO_SECURE environment variable. (default true)',
  ),
  Option(
    name: '--server',
    description: 'The address and port of the Kubernetes API server',
    args: Arg(name: 'string'),
  ),
  Option(
    name: '--tls-server-name',
    description:
        'If Provided, This name will be used to validate server certificate. '
        'If this is not provided',
    args: Arg(name: 'string'),
  ),
  Option(
    name: '--token',
    description: 'Bearer token for authentication to the API server',
    args: Arg(name: 'string'),
  ),
  Option(
    name: '--user',
    description: 'The name of the kubeconfig user to use',
    args: Arg(name: 'string'),
  ),
  Option(
    name: '--username',
    description: 'Username for basic authentication to the API server',
    args: Arg(name: 'string'),
  ),
  Option(
    name: ['--verbose', '-v'],
    description: 'Enabled verbose logging i.e. --loglevel debug',
  ),
];