restoreRestoreExactOptions top-level property

List<Option> restoreRestoreExactOptions
final

Implementation

final List<Option> restoreRestoreExactOptions = [

  Option(
    name: '--source',
    description: 'Can be a disk image, /dev entry, or volume mountpoint',
    args: [
      Arg(
      name: 'source',
      description: 'Disk image, /dev entry, or volume mountpoint',
      template: 'filepaths'
    )
    ],
    dependsOn: ['--target', '--file']
  ),
  Option(
    name: '--target',
    description: 'Can be a /dev entry, or volume mountpoint',
    args: [
      Arg(
      name: 'target',
      description: '/dev entry, or volume mountpoint',
      template: 'filepaths'
    )
    ]
  ),
  Option(
    name: '--file',
    description: 'When performing a multicast restore, --file can be specified instead of --target',
    args: [
      Arg(
      name: 'source',
      description: 'Disk image, /dev entry, or volume mountpoint',
      template: 'filepaths'
    )
    ],
    dependsOn: ['--erase']
  ),
  Option(
    name: '--erase',
    description: 'Erases target and is required. --erase must always be used, as file copies are no longer supported by asr'
  ),
  Option(
    name: '--format',
    description: 'Specifies the destination filesystem format',
    args: [
      Arg(
      name: 'HFS+ | HFSX',
      description: 'Specify the destination filesystem format',
      isOptional: true
    )
    ]
  ),
  Option(
    name: '--noprompt',
    description: 'Suppresses the prompt which usually occurs before target'
  ),
  Option(
    name: '--timeout',
    description: 'Specifies num seconds that a multicast client should wait when no payload data has been received over a multicast stream before exiting',
    args: [
      Arg(
      name: 'num',
      description: 'Number of seconds that a multicast client should wait',
      defaultValue: '0',
      isOptional: true,
      suggestions: [

        FigSuggestion(name: '0')
      ]
    )
    ]
  ),
  Option(
    name: '--puppetstrings',
    description: 'Provide progress output that is easy for another program to parse'
  ),
  Option(
    name: '--noverify',
    description: 'Skips the verification steps normally taken to ensure that a volume has been properly restored'
  ),
  Option(
    name: '--allowfragmentedcatalog',
    description: 'Allows restores to proceed even if the source\'s catalog file is fragmented'
  ),
  Option(
    name: '--SHA256',
    description: 'Forces the restore to use the SHA-256 hash in the image during verification'
  ),
  Option(
    name: '--sourcevolumename',
    description: 'Tells asr which volume in the source container to invert when doing an APFS restore'
  ),
  Option(
    name: '--sourcevolumeUUID',
    description: 'Tells asr which volume in the source container to invert when doing an APFS restore'
  ),
  Option(
    name: '--useReplication',
    description: 'Forces asr to use replication for restoring APFS volumes'
  ),
  Option(
    name: '--useInverter',
    description: 'Forces asr to use the inverter for restoring APFS volumes'
  ),
  Option(
    name: '--toSnapshot',
    description: 'Specifies the snapshot on the source APFS volume to restore to the target APFS volume'
  ),
  Option(
    name: '--fromSnapshot',
    description: 'Names a snapshot on the source APFS volume to use in combination with --toSnapshot to specify a snapshot delta to restore to the target APFS volume'
  )
];