notBunDevFlags top-level property

List<FigOption> notBunDevFlags
final

Implementation

final List<FigOption> notBunDevFlags = [
  FigOption(
      name: '--hot',
      description:
          'Enable auto reload in the Bun runtime, test runner, or bundler',
      priority: 50),
  FigOption(
      name: '--watch',
      description: 'Automatically restart the process on file change',
      priority: 50),
  FigOption(
      name: '--no-install',
      description: 'Disable auto install in the Bun runtime'),
  FigOption(
      name: '-i',
      description:
          'Automatically install dependencies and use global cache in Bun\'s runtime, equivalent to --install=fallback'),
  FigOption(name: '--install', args: [
    FigArg(
        name: 'arg',
        description:
            'Install dependencies automatically when no node_modules are present, default: "auto". "force" to ignore node_modules, fallback to install any missing',
        suggestions: [
          const FigSuggestion(name: 'auto'),
          const FigSuggestion(name: 'force'),
          const FigSuggestion(name: 'fallback'),
          const FigSuggestion(name: 'disable')
        ])
  ]),
  FigOption(
      name: '--prefer-offline',
      description:
          'Skip staleness checks for packages in the Bun runtime and resolve from disk'),
  FigOption(
      name: '--prefer-latest',
      description:
          'Use the latest matching versions of packages in the Bun runtime, always checking npm'),
  FigOption(
      name: '--silent', description: 'Don\'t repeat the command for bun run')
];