testOnlyParams top-level property
Implementation
final List<FigOption> testOnlyParams = [
FigOption(
name: '--timeout',
description: 'Set the per-test timeout in milliseconds, default is 5000',
args: [FigArg(name: 'number')]),
FigOption(name: '--update-snapshots', description: 'Update snapshot files'),
FigOption(
name: '--rerun-each',
description:
'Re-run each test file <NUMBER> times, helps catch certain bugs',
args: [FigArg(name: 'number')]),
FigOption(
name: '--only',
description: 'Only run tests that are marked with "test.only()"'),
FigOption(
name: '--todo',
description: 'Include tests that are marked with "test.todo()"'),
FigOption(name: '--coverage', description: 'Generate a coverage profile'),
FigOption(
name: '--bail',
description:
'Exit the test suite after <NUMBER> failures. If you do not specify a number, it defaults to 1',
args: [FigArg(name: 'number', isOptional: true)]),
FigOption(
name: ['-t', '--test-name-pattern'],
description: 'Run only tests with a name that matches the given regex',
args: [FigArg(name: 'pattern')])
];