capacitorSubcommands top-level property

List<FigSubcommand> capacitorSubcommands
final

Implementation

final List<FigSubcommand> capacitorSubcommands = [
  FigSubcommand(
    name: 'add',
    description: 'Add a native platform project to your app',
    args: [
      FigArg(
        name: 'platform',
        suggestions: _platforms,
      ),
    ],
  ),
  FigSubcommand(
    name: 'copy',
    description:
        'Copy the web app build and Capacitor configuration file into the native platform project. Run this each time you make changes to your web app or change a configuration value',
    priority: 51,
    args: [
      FigArg(
        name: 'platform',
        suggestions: _platforms,
        isOptional: true,
      ),
    ],
  ),
  FigSubcommand(
    name: 'ls',
    description: 'List all installed Cordova and Capacitor plugins',
    args: [
      FigArg(
        name: 'platform',
        suggestions: _platforms,
        isOptional: true,
      ),
    ],
  ),
  FigSubcommand(
    name: 'open',
    description:
        'Opens the native project workspace in the specified native IDE (Xcode for iOS, Android Studio for Android)',
    priority: 51,
    args: [
      FigArg(
        name: 'platform',
        suggestions: _platforms,
      ),
    ],
  ),
  FigSubcommand(
    name: 'run',
    description:
        'Opens the native project workspace in the specified native IDE (Xcode for iOS, Android Studio for Android)',
    priority: 51,
    args: [
      FigArg(
        name: 'platform',
        suggestions: _platforms,
      ),
    ],
    options: [
      FigOption(
        name: '--list',
        description:
            'Print a list of target devices available to the given platform',
        icon: '📱',
      ),
      FigOption(
        name: '--target',
        description: 'Run on a specific target device',
        icon: '📱',
        args: [
          FigArg(
            name: 'target',
            generators: [_targetGenerator],
          ),
        ],
      ),
    ],
  ),
  FigSubcommand(
    name: 'sync',
    description: 'This command runs copy and then update',
    args: [
      FigArg(
        name: 'platform',
        suggestions: _platforms,
        isOptional: true,
      ),
    ],
    options: [
      FigOption(
        name: '--deployment',
        description:
            'Podfile.lock won\'t be deleted and pod install will use --deployment option',
      ),
      FigOption(
        name: '--inline',
        description:
            'After syncing, all JS source maps will be inlined allowing for debugging an Android Web View in Chromium based browsers',
      ),
    ],
  ),
  FigSubcommand(
    name: 'update',
    description:
        'Updates the native plugins and dependencies referenced in package.json',
    args: [
      FigArg(
        name: 'platform',
        suggestions: _platforms,
        isOptional: true,
      ),
    ],
    options: [
      FigOption(
        name: '--deployment',
        description:
            'Podfile.lock won\'t be deleted and pod install will use --deployment option',
      ),
    ],
  ),
];