Package class

Constructors

Package({required String name, required String version, required String id, String? description, String? source, required List<Target> targets, required List<Dependency> dependencies})
Package.fromJson(Map<String, dynamic> json)
factory

Properties

dependencies List<Dependency>
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String?
final
targets List<Target>
final
version String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited