Version class

Constructors

Version({required String num, required int downloads, required String createdAt, required bool yanked})
Version.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt String
final
downloads int
final
hashCode int
The hash code for this object.
no setterinherited
num String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
yanked bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited