aotOptions top-level property

List<FigOption> aotOptions
final

AOT 编译选项列表

Implementation

final List<FigOption> aotOptions = [
  define,
  FigOption(
    name: '--enable-asserts',
    description: 'Enable assert statements',
  ),
  FigOption(
    name: ['-p', '--packages'],
    description:
        'Get package locations from the specified file instead of .packages. '
        '<path> can be relative or absolute',
    args: [
      FigArg(
        name: 'args-path',
        description: 'The path to draw packages from',
        template: 'filepaths',
      ),
    ],
  ),
  FigOption(
    name: ['--no-sound-null-safety', '--sound-null-safety'],
    description: 'Respect the nullability of types at runtime',
  ),
  FigOption(
    name: ['-S', '--save-debugging-info'],
    description:
        'Remove debugging information from the output and save it separately '
        'to the specified file. <path> can be relative or absolute',
    args: [
      FigArg(
        name: 'debug-info-path',
        description: 'The path to write debugging info to',
        template: 'filepaths',
      ),
    ],
  ),
];