DenoConfigurationFileSchema class

Implementers

Constructors

DenoConfigurationFileSchema({Map<String, dynamic>? compilerOptions, String? importMap, Map<String, dynamic>? lint, Map<String, dynamic>? fmt, Map<String, String>? tasks, Map<String, dynamic>? unknown})
DenoConfigurationFileSchema.fromJson(Map<String, dynamic> json)
factory

Properties

compilerOptions → Map<String, dynamic>?
final
fmt → Map<String, dynamic>?
final
hashCode → int
The hash code for this object.
no setterinherited
importMap → String?
final
lint → Map<String, dynamic>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tasks → Map<String, String>?
final
unknown → Map<String, dynamic>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited