InterfaceDef class

Constructors

InterfaceDef({required List<InterfaceMethodDef> methods, required List<InterfacePropertyDef> properties})
InterfaceDef.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
methods List<InterfaceMethodDef>
final
properties List<InterfacePropertyDef>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited