DenoConfigurationFile class

Inheritance

Constructors

DenoConfigurationFile({Map<String, dynamic>? compilerOptions, String? importMap, Map<String, dynamic>? lint, Map<String, dynamic>? fmt, Map<String, String>? tasks, Map<String, dynamic>? unknown, Map<String, dynamic>? fig})
DenoConfigurationFile.fromJson(Map<String, dynamic> json)
factory

Properties

compilerOptions Map<String, dynamic>?
finalinherited
fig Map<String, dynamic>?
final
fmt Map<String, dynamic>?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
importMap String?
finalinherited
lint Map<String, dynamic>?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tasks Map<String, String>?
finalinherited
unknown Map<String, dynamic>?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited