helpSpec top-level property

FigSpec helpSpec
final

Completion spec for help CLI

Implementation

final FigSpec helpSpec = FigSpec(
  name: 'help',
  description: 'The dotnet help command opens up the reference page for more detailed information about the specified command at docs.microsoft.com',
  args: [
    Arg(
    name: 'command',
    description: 'Name of the .NET CLI command'
  )
  ]
);