msbuildSpec top-level property
Completion spec for msbuild CLI
Implementation
final FigSpec msbuildSpec = FigSpec(
name: 'msbuild',
description: 'The dotnet msbuild command allows access to a fully functional MSBuild'
);
Completion spec for msbuild CLI
final FigSpec msbuildSpec = FigSpec(
name: 'msbuild',
description: 'The dotnet msbuild command allows access to a fully functional MSBuild'
);