Action class

Constructors

Action({required String identifier, required String name, required String description, required String availability, required List<String> defaultBindings})
Action.fromJson(Map<String, dynamic> json)
factory

Properties

availability String
final
defaultBindings List<String>
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
identifier String
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited