ScriptFields class

Constructors

ScriptFields({required String name, required Map<String, dynamic> fields, required int relevanceScore, required String lastInvokedAt, required String lastInvokedAtByUser, required bool isOwnedByCurrentUser, String? namespace})
ScriptFields.fromJson(Map<String, dynamic> json)
factory

Properties

fields Map<String, dynamic>
final
hashCode int
The hash code for this object.
no setterinherited
isOwnedByCurrentUser bool
final
lastInvokedAt String
final
lastInvokedAtByUser String
final
name String
final
namespace String?
final
relevanceScore int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited