Setting class

Constructors

Setting({required String settingName, required String description, required String type, List? options, String? defaultValue})
Setting.fromJson(Map<String, dynamic> json)
factory

Properties

defaultValue String?
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
options List?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settingName String
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited