awaitFirstFrameWhenTracing top-level property

List<FigOption> awaitFirstFrameWhenTracing
final

Implementation

final List<FigOption> awaitFirstFrameWhenTracing = [
  FigOption(
    name: ['--await-first-frame-when-tracing'],
    description:
        'Whether to wait for the first frame when tracing startup ("--trace-startup"), or just dump the trace as soon as the application is running. The first frame is detected by looking for a Timeline event with the name "Rasterized first useful frame". By default, the widgets library\'s binding takes care of sending this event',
  ),
  FigOption(
    name: ['--no-await-first-frame-when-tracing'],
  ),
];