enabledFuchsia top-level property
Implementation
final List<FigOption> enabledFuchsia = [
FigOption(
name: ['--enable-fuchsia'],
description:
'Enable Flutter for Fuchsia. This setting will take effect on the master channel',
),
FigOption(
name: ['--no-enable-fuchsia'],
description:
'Disable Flutter for Fuchsia. This setting will take effect on the master channel',
),
];