keepAppRunning top-level property

List<FigOption> keepAppRunning
final

Implementation

final List<FigOption> keepAppRunning = [
  FigOption(
    name: ['--keep-app-running'],
    description:
        'Will keep the Flutter application running when done testing. By default, "flutter drive" stops the application after tests are finished, and --keep-app-running overrides this. On the other hand, if --use-existing-app is specified, then "flutter drive" instead defaults to leaving the application running, and --no-keep-app-running overrides it',
  ),
  FigOption(
    name: ['--no-keep-app-running'],
  ),
];