run top-level property
Implementation
final List<FigOption> run = [
debug,
profile,
FigOption(
name: ['--release'],
description: 'Build a release version of your app',
),
dartDefine,
FigOption(
name: ['--flavor'],
description:
'Build a custom app flavor as defined by platform-specific build setup. Supports the use of product flavors in Android Gradle scripts, and the use of custom Xcode schemes',
),
FigOption(
name: ['--web-renderer'],
description:
'The renderer implementation to use when building for the web. Possible values are: html - always use the HTML renderer. This renderer uses a combination of HTML, CSS, SVG, 2D Canvas, and WebGL. This is the default. canvaskit - always use the CanvasKit renderer. This renderer uses WebGL and WebAssembly to render graphics. auto - use the HTML renderer on mobile devices, and CanvasKit on desktop devices. [auto (default), canvaskit, html]',
),
FigOption(
name: ['--trace-startup'],
description:
'Trace application startup, then exit, saving the trace to a file',
),
FigOption(
name: ['--verbose-system-logs'],
description: 'Include verbose logging from the flutter engine',
),
FigOption(
name: ['--cache-sksl'],
description: 'Only cache the shader in SkSL instead of binary or GLSL',
),
FigOption(
name: ['--dump-skp-on-shader-compilation'],
description:
'Automatically dump the skp that triggers new shader compilations. This is useful for writing custom ShaderWarmUp to reduce jank. By default, this is not enabled to reduce the overhead. This is only available in profile or debug build',
),
FigOption(
name: ['--purge-persistent-cache'],
description:
'Removes all existing persistent caches. This allows reproducing shader compilation jank that normally only happens the first time an app is run, or for reliable testing of compilation jank fixes (e.g. shader warm-up)',
),
FigOption(
name: ['--route'],
description: 'Which route to load when running the app',
),
FigOption(
name: ['--vmservice-out-file'],
description:
'A file to write the attached vmservice uri to after an application is started. e.g. project/example/out.txt',
args: [
FigArg(
name: '.txt output file path',
template: 'filepaths',
),
],
),
FigOption(
name: ['--use-application-binary'],
description:
'Specify a pre-built application binary to use when running. For android applications, this must be the path to an APK. For iOS applications, the path to an IPA. Other device types do not yet support prebuilt application binaries. e.g. path/to/app.apk',
args: [
FigArg(
name: 'file path to .apk',
template: 'filepaths',
),
],
),
FigOption(
name: ['--endless-trace-buffer'],
description:
'Enable tracing to the endless tracer. This is useful when recording huge amounts of traces. If we need to use endless buffer to record startup traces, we can combine the ("--trace-startup"). For example, flutter run --trace-startup --endless-trace-buffer',
),
FigOption(
name: ['--trace-systrace'],
description:
'Enable tracing to the system tracer. This is only useful on platforms where such a tracer is available (Android and Fuchsia)',
),
FigOption(
name: ['--trace-skia'],
description:
'Enable tracing of Skia code. This is useful when debugging the raster thread (formerly known as the GPU thread). By default, Flutter will not log skia code',
),
FigOption(
name: ['-a', '--dart-entrypoint-args'],
insertValue: '--dart-entrypoint-args',
description:
'Pass a list of arguments to the Dart entrypoint at application startup. By default this is main(List<String> args). Specify this option multiple times each with one argument to pass multiple arguments to the Dart entrypoint. Currently this is only supported on desktop platforms',
isRepeatable: true,
),
target,
observatoryPort,
deviceVmservicePort,
hostVmServicePort,
...pub,
...trackWidgetCreation,
...nullAssertions,
deviceUser,
deviceTimeout,
FigOption(
name: ['--dds-port'],
description:
'When this value is provided, the Dart Development Service (DDS) will be bound to the provided port. Specifying port 0 (the default) will find a random free port',
),
FigOption(
name: ['--devtools-server-address'],
description:
'When this value is provided, the Flutter tool will not spin up a new DevTools server instance, but instead will use the one provided at this address',
),
];