singleWidgetReloadOptimization top-level property
Implementation
final List<FigOption> singleWidgetReloadOptimization = [
FigOption(
name: ['--single-widget-reload-optimization'],
description:
'Enable Hot reload optimization for changes to class body of a single widget. This setting will take effect on the master, dev, and beta channels',
),
FigOption(
name: ['--no-single-widget-reload-optimization'],
description:
'Disable Hot reload optimization for changes to class body of a single widget. This setting will take effect on the master, dev, and beta channels',
),
];