syntheticPackage top-level property

List<FigOption> syntheticPackage
final

Implementation

final List<FigOption> syntheticPackage = [
  FigOption(
    name: ['--synthetic-package'],
    description:
        "Determines that the generated output files will be generated as a synthetic package or at a specified directory in the Flutter project. \n\nThis flag is set to true by default. \n\nWhen synthetic-package is set to false, it will generate the localizations files in the directory specified by arb-dir by default. \n\nIf output-dir is specified, files will be generated there",
  ),
  FigOption(
    name: ['--no-synthetic-package'],
  ),
];