useDeferredLoading top-level property
Implementation
final List<FigOption> useDeferredLoading = [
FigOption(
name: ['--use-deferred-loading'],
description:
"Generate the Dart localization file with locales imported as deferred, allowing for lazy loading of each locale in Flutter web. \n\nThis can reduce a web app’s initial startup time by decreasing the size of the JavaScript bundle. When this flag is set to true, the messages for a particular locale are only downloaded and loaded by the Flutter app as they are needed. For projects with a lot of different locales and many localization strings, it can be an performance improvement to have deferred loading. For projects with a small number of locales, the difference is negligible, and might slow down the start up compared to bundling the localizations with the rest of the application. \n\nNote that this flag does not affect other platforms such as mobile or desktop",
),
FigOption(
name: ['--no-use-deferred-loading'],
description:
"Don't generate the Dart localization file with locales imported as deferred",
),
];