daemonServices top-level property

List<FigSuggestion> daemonServices
final

Implementation

final List<FigSuggestion> daemonServices = [
  FigSuggestion(
      name: 'upload-pack',
      description:
          'This serves git fetch-pack and git ls-remote clients. It is enabled by default, but a repository can disable it by setting daemon.uploadpack configuration item to false'),
  FigSuggestion(
      name: 'upload-archive',
      description:
          'This serves git archive --remote. It is disabled by default, but a repository can enable it by setting daemon.uploadarch configuration item to true'),
  FigSuggestion(
      name: 'receive-pack',
      description:
          'This serves git send-pack clients, allowing anonymous push. It is disabled by default, as there is no authentication in the protocol (in other words, anybody can push anything into the repository, including removal of refs). This is solely meant for a closed LAN setting where everybody is friendly. This service can be enabled by setting daemon.receivepack configuration item to true')
];