buildModeSuggestions top-level property

List<FigSuggestion> buildModeSuggestions
final

Implementation

final buildModeSuggestions = [
  FigSuggestion(
      name: 'archive',
      description: 'Build the listed non-main packages into .a files'),
  FigSuggestion(
      name: 'c-archive',
      description:
          'Build the listed main package, plus all packages it imports, into a C archive file'),
  FigSuggestion(
      name: 'c-shared',
      description:
          'Build the listed main package, plus all packages it imports, into a C shared library'),
  FigSuggestion(
      name: 'default',
      description:
          'Listed main packages are built into executables and listed non-main packages are built into .a files'),
  FigSuggestion(
      name: 'shared',
      description:
          'Combine all the listed non-main packages into a single shared library that will be used when building with the -linkshared option'),
  FigSuggestion(
      name: 'exe',
      description:
          'Build the listed main packages and everything they import into executables'),
  FigSuggestion(
      name: 'pie',
      description:
          'Build the listed main packages and everything they import into position independent executables (PIE)'),
  FigSuggestion(
      name: 'plugin',
      description:
          'Build the listed main packages, plus all packages that they import, into a Go plugin'),
];