resolutionAndExecutionOptions top-level property

List<FigOption> resolutionAndExecutionOptions
final

Implementation

final resolutionAndExecutionOptions = [
  Option(name: ['-n'], description: 'Print the commands but do not run them'),
  Option(
      name: ['-v'],
      description: 'Print the names of packages as they are compiled'),
  Option(name: ['-x'], description: 'Print the commands'),
  Option(
      name: ['-tags'],
      description:
          'A comma-separated list of build tags to consider satisfied during the build',
      args: [Arg(name: 'tags')]),
  Option(
      name: ['-toolexec'],
      insertValue: '-toolexec \'{cursor}\'',
      description:
          'A program to use to invoke toolchain programs like vet and asm',
      args: [Arg(name: 'cmd')]),
];