consoleModeArg top-level property
Implementation
final FigArg consoleModeArg = FigArg(
name: 'mode',
defaultValue: 'auto',
suggestions: [
FigSuggestion(
name: 'auto',
description:
'Enables color and other rich output in the console output when the build process is attached to a console, or to generate plain text only when not attached to a console',
),
FigSuggestion(
name: 'plain',
description:
'Disables all color and other rich output in the console output. This is the default when Gradle is not attached to a terminal',
),
FigSuggestion(
name: 'rich',
description:
'Enables color and other rich output in the console output, regardless of whether the build process is not attached to a console',
),
FigSuggestion(
name: 'verbose',
description:
'Enables color and other rich output like the rich, but output task names and outcomes at the lifecycle log level, as is done by default in Gradle 3.5 and earlier',
),
],
);