ifSpec top-level property
Completion spec for if CLI
Implementation
final FigSpec ifSpec = FigSpec(
name: 'if',
description: 'Conditionally execute based on the return value of a command',
args: [
Arg(
)
]
);
Completion spec for if CLI
final FigSpec ifSpec = FigSpec(
name: 'if',
description: 'Conditionally execute based on the return value of a command',
args: [
Arg(
)
]
);