sharedOpts top-level property

Map<String, FigOption> sharedOpts
final

Implementation

final Map<String, FigOption> sharedOpts = {
  'help': FigOption(
    name: ['-h', '--help'],
    description: 'Displays help on commandline options',
    isPersistent: true,
  ),
  'helpAll': FigOption(
    name: '--help-all',
    description: 'Displays help including Qt specific options',
    isPersistent: true,
  ),
  'verbose': FigOption(
    name: ['-v', '--verbose'],
    description:
        "Increase logging verbosity. Repeat the 'v' in the short option for more detail. Maximum verbosity is obtained with 4 (or more) v's, i.e. -vvvv",
    isPersistent: true,
  ),
  'format': FigOption(
    name: '--format',
    description:
        'Output list in the requested format. Valid formats are: table (default), json, csv and yaml',
    args: FigArg(
      name: 'format',
      suggestions: [
        FigSuggestion(name: 'table'),
        FigSuggestion(name: 'json'),
        FigSuggestion(name: 'csv'),
        FigSuggestion(name: 'yaml'),
      ],
      defaultValue: 'table',
    ),
  ),
  'timeout': FigOption(
    name: '--timeout',
    description:
        'Maximum time, in seconds, to wait for the command to complete. Note that some background operations may continue beyond that. By default, instance startup and initialization is limited to 5 minutes each',
    args: FigArg(
      name: 'timeout',
      defaultValue: '300',
    ),
  ),
};