dryRunOption top-level property

Option dryRunOption
final

Implementation

final Option dryRunOption = Option(
  name: '--dry-run',
  description:
      "Indicates that you don't want npm to make any changes and that it should only report what it would have done",
);