scriptShellOption top-level property

Option scriptShellOption
final

Implementation

final Option scriptShellOption = Option(
  name: '--script-shell',
  description:
      'The shell to use for scripts run with the npm exec, npm run and npm init <pkg> commands',
  args: [Arg(name: 'script-shell')],
);