workSpaceOptions top-level property

List<Option> workSpaceOptions
final

Implementation

final List<Option> workSpaceOptions = [
  Option(
    name: ['-w', '--workspace'],
    description:
        'Enable running a command in the context of the configured workspaces of the current project',
    args: [
      Arg(name: 'workspace', generators: workspaceGenerator, isVariadic: true)
    ],
  ),
  Option(
    name: ['-ws', '--workspaces'],
    description:
        'Enable running a command in the context of all the configured workspaces',
  ),
];