buildIosOptions top-level property
Implementation
final List<FigOption> buildIosOptions = [
FigOption(
name: ['--for-device'],
description:
'Produces an application package that you can deploy on device. Otherwise, produces a build that you can run only in the native iOS Simulator',
),
FigOption(
name: ['--i-cloud-container-environment'],
description:
'Adds the passed iCloudContainerEnvironment when exporting an application package with the --for-device option',
dependsOn: ['--for-device'],
),
FigOption(
name: ['--team-id'],
description:
'If used without parameter, lists all team names and ids. If used with team name or id, it will switch to automatic signing mode and configure the .xcodeproj file of your app. In this case .xcconfig should not contain any provisioning/team id flags',
args: [FigArg(name: 'team id', isOptional: true)],
),
FigOption(
name: ['--provision'],
description:
'If used without parameter, lists all eligible provisioning profiles. If used with UUID or name of your provisioning profile, it will switch to manual signing mode and configure the .xcodeproj file of your app',
args: [FigArg(name: 'uuid', isOptional: true)],
),
];