debugBothOptions top-level property

List<FigOption> debugBothOptions
final

Implementation

final List<FigOption> debugBothOptions = [
  ...platformGeneralOptions,
  FigOption(
    name: ['--debug-brk'],
    description:
        'Prepares, builds and deploys the application package on a device or in an emulator, and stops at the first JavaScript line until either the debugger frontend connects or a 30 seconds timeout elapses',
  ),
  FigOption(
    name: ['--start'],
    description: 'Attaches the debug tools to a deployed and running app',
  ),
  FigOption(
    name: ['--no-watch'],
    description: 'Changes in your code will not be livesynced',
  ),
];