debugCommand top-level property

FigSubcommand debugCommand
final

Implementation

final FigSubcommand debugCommand = FigSubcommand(
  name: ['debug'],
  description:
      'Initiates a debugging session for your project on a connected device or native emulator',
  subcommands: [
    FigSubcommand(
      name: ['android'],
      description:
          'Start a debugging session for your project on a connected Android device or Android emulator',
      options: [...debugBothOptions, ...debugAndroidOptions],
      priority: 90,
    ),
    FigSubcommand(
      name: ['ios'],
      description:
          'Start a debugging session for your project on a connected iOS device or in the native iOS simulator',
      options: [...debugBothOptions, ...debugIosOptions],
      priority: 90,
    ),
  ],
  options: [helpOption('debug')],
);