platformCommand top-level property

FigSubcommand platformCommand
final

Implementation

final FigSubcommand platformCommand = FigSubcommand(
  name: ['platform'],
  description:
      'Lists all platforms that the project currently targets. You can build and deploy your project only for these target platforms',
  subcommands: [
    FigSubcommand(
      name: ['list'],
      description:
          'Lists all platforms that the project currently targets. You can build and deploy your project only for these target platforms',
    ),
    FigSubcommand(
      name: ['add'],
      description:
          'Configures the current project to target the selected platform',
      subcommands: [
        FigSubcommand(
          name: ['android'],
          description: 'The latest android platform',
          options: [frameworkPathOption],
        ),
        FigSubcommand(
          name: ['android@[Version]'],
          insertValue: 'android@{cursor}',
          description: 'The defined android platform eg. 1.0.0',
          options: [frameworkPathOption],
        ),
        FigSubcommand(
          name: ['ios'],
          description: 'The latest ios platform',
          options: [frameworkPathOption],
        ),
        FigSubcommand(
          name: ['ios@[Version]'],
          insertValue: 'ios@{cursor}',
          description: 'The defined ios platform eg. 1.0.0',
          options: [frameworkPathOption],
        ),
      ],
    ),
    FigSubcommand(
      name: ['remove'],
      description:
          'Removes the selected platform from the platforms that the project currently targets',
      subcommands: [
        FigSubcommand(
            name: ['android'], description: 'The latest android platform'),
        FigSubcommand(name: ['ios'], description: 'The latest ios platform'),
      ],
    ),
    FigSubcommand(
      name: ['update'],
      description:
          'Updates the NativeScript runtime for the specified platform',
      subcommands: [
        FigSubcommand(
            name: ['android'], description: 'The latest android platform'),
        FigSubcommand(name: ['ios'], description: 'The latest ios platform'),
      ],
    ),
  ],
  options: [helpOption('platform')],
);