platformEnvOptions top-level property

List<FigOption> platformEnvOptions
final

Implementation

final List<FigOption> platformEnvOptions = [
  FigOption(
    name: ['--env.aot'],
    description: 'Creates an Ahead-Of-Time build (Angular only)',
  ),
  FigOption(
    name: ['--env.uglify'],
    description: 'Provides basic obfuscation and smaller app size',
  ),
  FigOption(
    name: ['--env.report'],
    description:
        'Creates a Webpack report inside a /report folder in the root folder',
  ),
  FigOption(
    name: ['--env.sourceMap'],
    description: 'Creates inline source maps',
  ),
  FigOption(
    name: ['--env.hiddenSourceMap'],
    description:
        'Creates sources maps in the root folder (useful for Crashlytics usage with bundled app in release)',
  ),
  FigOption(
    name: ['--env.verbose'],
    description: 'Prints verbose logs and the internal config before building',
  ),
  FigOption(
    name: ['--env.production'],
    description: 'Enable production mode (will minify the code)',
  ),
  FigOption(
    name: ['--env.replace=from:to'],
    description:
        'Add file replacement rules. For source files (.js and .ts) this will add a new alias to the config, for everything else, this will add a new copy rule',
    insertValue: '--env.replace={cursor}:',
    requiresSeparator: true,
  ),
];