proxyCommand top-level property

FigSubcommand proxyCommand
final

Implementation

final FigSubcommand proxyCommand = FigSubcommand(
  name: ['proxy'],
  description: 'Displays the current proxy settings of the NativeScript CLI',
  subcommands: [
    FigSubcommand(
      name: ['clear'],
      description:
          'Clears the currently configured proxy settings of the NativeScript CLI',
    ),
    FigSubcommand(
      name: ['set'],
      description: 'Sets the proxy settings of the NativeScript CLI',
      args: [
        FigArg(
            name: 'proxy url',
            description:
                'Full url of the proxy. For example, http://127.0.0.1:8888. If you do not provide the url when running the command, the NativeScript CLI will prompt you to provide it'),
        FigArg(
            name: 'username',
            description: 'Credentials for the proxy',
            isOptional: true),
        FigArg(
            name: 'password',
            description: 'Credentials for the proxy',
            isOptional: true),
      ],
      options: [
        FigOption(
          name: ['--insecure'],
          description:
              "Allows insecure SSL connections and transfers to be performed. In case your proxy doesn't have a CA certificate or has an invalid one you need to use this flag",
        ),
      ],
    ),
  ],
  options: [helpOption('proxy')],
);