testBothOptions top-level property

List<FigOption> testBothOptions
final

Implementation

final List<FigOption> testBothOptions = [
  FigOption(
    name: ['--watch'],
    description:
        'When you save changes to the project, changes are automatically synchronized to the connected device and tests are re-run',
  ),
  FigOption(
    name: ['--debug-brk'],
    description:
        'Runs the tests under the debugger. The debugger will break just before your tests are executed, so you have a chance to place breakpoints',
  ),
  justLaunchOption,
  forceOption,
  deviceOption,
  emulatorOption,
];