usageReportingCommand top-level property

FigSubcommand usageReportingCommand
final

Implementation

final FigSubcommand usageReportingCommand = FigSubcommand(
  name: ['usage-reporting'],
  description:
      'Configures anonymous usage reporting for the NativeScript CLI. All data gathered is used strictly for improving the product and will never be used to identify or contact you',
  subcommands: [
    FigSubcommand(
      name: ['status'],
      description:
          'Shows the current configuration for anonymous usage reporting for the NativeScript CLI',
    ),
    FigSubcommand(
      name: ['enable'],
      description: 'Enables anonymous usage reporting',
    ),
    FigSubcommand(
      name: ['disable'],
      description: 'Disables anonymous usage reporting',
    ),
  ],
  options: [helpOption('usage-reporting')],
  priority: 1,
);