FILTER_OPTION top-level property

FigOption FILTER_OPTION
final

FILTER 选项

Implementation

final FigOption FILTER_OPTION = FigOption(
  name: '--filter',
  description:
      'Filtering allows you to restrict commands to specific subsets of packages. pnpm supports a rich selector syntax for picking packages by name or by relation. More details: https://pnpm.io/filtering',
  args: [
    FigArg(
      name: 'Filepath / Package',
      description:
          'To only select packages under the specified directory, you may specify any absolute path, typically in POSIX format',
      template: 'filepaths',
    ),
  ],
);