INSTALL_OPTIONS top-level property

List<Option> INSTALL_OPTIONS
final

Implementation

final List<Option> INSTALL_OPTIONS = [
  Option(
      name: ['-P', '--save-prod'],
      // TS_UNCONVERTED_START (description)
// 'Pnpm will not install any package listed in devDependencies if the NODE_ENV environment variable is set to production.
// Use this flag to instruct pnpm to ignore NODE_ENV and take its production status from this flag instead'
// TS_UNCONVERTED_END
      description: null),
  Option(
      name: ['-D', '--save-dev'],
      description:
          'Only devDependencies are installed regardless of the NODE_ENV'),
  Option(
      name: '--no-optional',
      description: 'OptionalDependencies are not installed'),
  Option(
      name: '--lockfile-only',
      description:
          'When used, only updates pnpm-lock.yaml and package.json instead of checking node_modules and downloading dependencies'),
  Option(
      name: '--frozen-lockfile',
      description:
          'If true, pnpm doesn\'t generate a lockfile and fails to install if the lockfile is out of sync with the manifest / an update is needed or no lockfile is present'),
  Option(
      name: '--use-store-server',
      description:
          'Starts a store server in the background. The store server will keep running after installation is done. To stop the store server, run pnpm server stop'),
  Option(
      name: '--shamefully-hoist',
      description:
          'Creates a flat node_modules structure, similar to that of npm or yarn. WARNING: This is highly discouraged')
];