publishSpec top-level property

FigSpec publishSpec
final

Completion spec for publish CLI

Implementation

final FigSpec publishSpec = FigSpec(
  name: 'publish',
  description: '',
  subcommands: [

    Subcommand(
      name: 'new',
      description: 'Set up a new website in the current folder'
    ),
    Subcommand(
      name: 'run',
      description: 'Generate and run a localhost server on default port 8000 for the website in the current folder',
      parserDirectives: ParserDirectives(
        flagsArePosixNoncompliant: true
      ),
      options: [

        Option(
          name: ['-p', '--port'],
          description: 'Customize the port',
          args: [
            Arg(
            name: 'port',
            defaultValue: '8000'
          )
          ]
        )
      ]
    ),
    Subcommand(
      name: 'deploy',
      description: 'Generate and deploy the website in the current folder'
    ),
    Subcommand(
      name: 'generate',
      description: 'Generate the website in the current folder'
    )
  ],
  options: [

    Option(
      name: ['--help', '-h'],
      description: 'Show help for publish'
    )
  ]
);