shelveSpec top-level property

FigSpec shelveSpec
final

Completion spec for shelve CLI

Implementation

final FigSpec shelveSpec = FigSpec(
  name: 'shelve',
  description: 'Shelve CLI a command-line interface designed for the Shelve platform. This tool enables users to authenticate with Shelve, facilitating the seamless transfer of environment variables for project collaboration within a team directly through the terminal interface',
  options: [

    Option(
      name: ['--help', '-h'],
      description: 'Show help',
      isPersistent: true
    )
  ]
);