speedtestCliSpec top-level property

FigSpec speedtestCliSpec
final

Completion spec for speedtest-cli CLI

Implementation

final FigSpec speedtestCliSpec = FigSpec(
  name: 'speedtest-cli',
  description: 'Command line interface for testing internet bandwidth using speedtest.net',
  options: [

    Option(
      name: ['--help', '-h'],
      description: 'Show this help message and exit'
    ),
    Option(
      name: '--no-download',
      description: 'Do not perform download test'
    ),
    Option(
      name: '--no-upload',
      description: 'Do not perform upload test'
    ),
    Option(
      name: '--single',
      description: 'Only use a single connection instead of multiple. This simulates a typical file transfer'
    ),
    Option(
      name: '--bytes',
      description: 'Display values in bytes instead of bits. Does not affect the image generated by --share, nor the output from --json or --csv'
    ),
    Option(
      name: '--share',
      description: 'Generate and provide a URL to the speedtest.net share results image, not displayed with --csv'
    ),
    Option(
      name: '--simple',
      description: 'Suppress verbose output, only show basic information'
    ),
    Option(
      name: '--csv',
      description: 'Suppress verbose output, only show basic information in CSV format. Speeds listed in bit/s and not affected by --bytes'
    ),
    Option(
      name: '--csv-delimiter',
      description: 'Single character delimiter to use in CSV ouput. Default \',\'',
      args: [
        Arg(
        name: 'CSV_DELIMITE'
      )
      ]
    ),
    Option(
      name: '--csv-header',
      description: 'Print CSV headers'
    ),
    Option(
      name: '--json',
      description: 'Suppress verbose output, only show basic information in JSON format. Speeds listed in bit/s and not affected by --bytes'
    ),
    Option(
      name: '--list',
      description: 'Display a list of speedtest.net servers sorted by distance'
    ),
    Option(
      name: '--server',
      description: 'Specify a server ID to test against. Can be supplied multiple times',
      args: [
        Arg(
        name: 'SERVE'
      )
      ]
    ),
    Option(
      name: '--exclude',
      description: 'Exclude a server from selection. Can be supplied multiple times',
      args: [
        Arg(
        name: 'EXCLUD'
      )
      ]
    ),
    Option(
      name: '--mini',
      description: 'URL for the Speedtest Mini server',
      args: [
        Arg(
        name: 'MIN'
      )
      ]
    ),
    Option(
      name: '--source',
      description: 'Source IP address to bind to',
      args: [
        Arg(
        name: 'SOURC'
      )
      ]
    ),
    Option(
      name: '--timeout',
      description: 'HTTP timeout in seconds. Default 10',
      args: [
        Arg(
        name: 'TIMEOU'
      )
      ]
    ),
    Option(
      name: '--secure',
      description: 'Use HTTPS instead of HTTP when communicating with speedtest.net operated servers'
    ),
    Option(
      name: '--no-pre-allocate',
      description: 'Do not pre allocate upload data. Pre allocation is enabled by default to improve upload performance. To support systems with insufficient memory, use this option to avoid a MemoryError'
    ),
    Option(
      name: '--version',
      description: 'Show the version number and exit'
    )
  ]
);