webhookSuggestions top-level property

List<FigSuggestion> webhookSuggestions
final

Implementation

final List<FigSuggestion> webhookSuggestions = [

  FigSuggestion(
    name: 'balance.available',
    description: 'Occurs whenever your Stripe balance has been updated (e.g., when a charge is available to be paid out). By default, Stripe automatically transfers funds in your balance to your bank account on a daily basis'
  ),
  FigSuggestion(
    name: 'charge.captured',
    description: 'Occurs whenever a previously uncaptured charge is captured'
  ),
  FigSuggestion(
    name: 'charge.dispute.created',
    description: 'Occurs whenever a customer disputes a charge with their bank'
  ),
  FigSuggestion(
    name: 'charge.failed',
    description: 'Occurs whenever a failed charge attempt occurs'
  ),
  FigSuggestion(
    name: 'charge.refunded',
    description: 'Occurs whenever a charge is refunded, including partial refunds'
  ),
  FigSuggestion(
    name: 'charge.succeeded',
    description: 'Occurs whenever a new charge is created and is successful'
  ),
  FigSuggestion(
    name: 'checkout.session.completed',
    description: 'Occurs when a Checkout Session has been successfully completed'
  ),
  FigSuggestion(
    name: 'customer.created',
    description: 'Occurs whenever a new customer is created'
  ),
  FigSuggestion(
    name: 'customer.deleted',
    description: 'Occurs whenever a customer is deleted'
  ),
  FigSuggestion(
    name: 'customer.source.created',
    description: 'Occurs whenever a new source is created for a customer'
  ),
  FigSuggestion(
    name: 'customer.source.updated',
    description: 'Occurs whenever a source\'s details are changed'
  ),
  FigSuggestion(
    name: 'customer.subscription.created',
    description: 'Occurs whenever a customer is signed up for a new plan'
  ),
  FigSuggestion(
    name: 'customer.subscription.deleted',
    description: 'Occurs whenever a customer\'s subscription ends'
  ),
  FigSuggestion(
    name: 'customer.subscription.updated',
    description: 'Occurs whenever a subscription changes (e.g., switching from one plan to another, or changing the status from trial to active)'
  ),
  FigSuggestion(
    name: 'customer.updated',
    description: 'Occurs whenever any property of a customer changes'
  ),
  FigSuggestion(
    name: 'invoice.created',
    description: 'Occurs whenever a new invoice is created'
  ),
  FigSuggestion(
    name: 'invoice.finalized',
    description: 'Occurs whenever a draft invoice is finalized and updated to be an open invoice'
  ),
  FigSuggestion(
    name: 'invoice.payment_failed',
    description: 'Occurs whenever an invoice payment attempt fails, due either to a declined payment or to the lack of a stored payment method'
  ),
  FigSuggestion(
    name: 'invoice.payment_succeeded',
    description: 'Occurs whenever an invoice payment attempt succeeds'
  ),
  FigSuggestion(
    name: 'invoice.updated',
    description: 'Occurs whenever an invoice changes (e.g., the invoice amount)'
  ),
  FigSuggestion(
    name: 'issuing_authorization.request',
    description: 'Represents a synchronous request for authorization'
  ),
  FigSuggestion(
    name: 'issuing_card.created',
    description: 'Occurs whenever a card is created'
  ),
  FigSuggestion(
    name: 'issuing_cardholder.created',
    description: 'Occurs whenever a cardholder is created'
  ),
  FigSuggestion(
    name: 'payment_intent.amount_capturable_updated',
    description: 'Occurs when a PaymentIntent has funds to be captured'
  ),
  FigSuggestion(
    name: 'payment_intent.canceled',
    description: 'Occurs when a PaymentIntent is canceled'
  ),
  FigSuggestion(
    name: 'payment_intent.created',
    description: 'Occurs when a new PaymentIntent is created'
  ),
  FigSuggestion(
    name: 'payment_intent.payment_failed',
    description: 'Occurs when a PaymentIntent has failed the attempt to create a payment method or a payment'
  ),
  FigSuggestion(
    name: 'payment_intent.succeeded',
    description: 'Occurs when a PaymentIntent has successfully completed payment'
  ),
  FigSuggestion(
    name: 'payment_method.attached',
    description: 'Occurs whenever a new payment method is attached to a customer'
  ),
  FigSuggestion(
    name: 'setup_intent.canceled',
    description: 'Occurs when a SetupIntent is canceled'
  ),
  FigSuggestion(
    name: 'setup_intent.created',
    description: 'Occurs when a new SetupIntent is created'
  ),
  FigSuggestion(
    name: 'setup_intent.setup_failed',
    description: 'Occurs when a SetupIntent has failed the attempt to setup a payment method'
  ),
  FigSuggestion(
    name: 'setup_intent.succeeded',
    description: 'Occurs when an SetupIntent has successfully setup a payment method'
  )
];