sysctlSpec top-level property

FigSpec sysctlSpec
final

Implementation

final FigSpec sysctlSpec = FigSpec(
  name: 'sysctl',
  description: 'Get or set kernel state',
  options: [
    FigOption(
      name: ['-A', '-a'],
      description: 'List all the currently available non-opaque values',
    ),
    FigOption(
      name: ['-b'],
      description: 'Force the value of the variable(s) to be output in raw, binary format',
    ),
    FigOption(
      name: ['-d'],
      description: 'Print the description of the variable instead of its value',
    ),
    FigOption(
      name: ['-e'],
      description: 'Separate the name and the value of the variable(s) with \'=\'',
      args: [
        FigArg(
          name: 'variable',
          isVariadic: true,
        ),
      ],
    ),
    FigOption(
      name: ['-h'],
      description: 'Format output for human, rather than machine, readability',
    ),
    FigOption(
      name: ['-i'],
      description: 'Ignore unknown OIDs',
    ),
    FigOption(
      name: ['-N'],
      description: 'Show only variable names, not their values',
    ),
    FigOption(
      name: ['-n'],
      description: 'Show only variable values, not their names',
    ),
    FigOption(
      name: ['-o'],
      description: 'Show opaque variables (which are normally suppressed)',
    ),
    FigOption(
      name: ['-q'],
      description: 'Suppress some warnings generated by sysctl to standard error',
    ),
    FigOption(
      name: ['-X'],
      description: 'Equivalent to -x -a (for compatibility)',
    ),
    FigOption(
      name: ['-x'],
      description: 'As -o, but prints a hex dump of the entire value instead of just the first few bytes',
    ),
  ],
  args: [
    FigArg(
      name: 'Variable names (and values if available)',
      isVariadic: true,
      isOptional: true,
      generators: [generateSysctlNames],
    ),
  ],
);