buildCommandOptions top-level property

List<Option> buildCommandOptions
final

Implementation

final List<Option> buildCommandOptions = [
  Option(
      name: '--package',
      description: 'Build a specific package in the workspace',
      args: [Arg(name: 'PACKAGE')]),
  Option(
      name: '--all-packages',
      description: 'Build all packages in the workspace'),
  Option(
      name: '-o',
      description:
          'The output directory to which distributions should be written',
      args: [Arg(name: 'OUT_DIR')]),
  Option(
      name: '--sdist',
      description:
          'Build a source distribution (\'sdist\') from the given directory'),
  Option(
      name: '--wheel',
      description:
          'Build a binary distribution (\'wheel\') from the given directory'),
  Option(
      name: '--no-build-logs', description: 'Hide logs from the build backend'),
  Option(
      name: '--force-pep517',
      description:
          'Always build through PEP 517, don\'t use the fast path for the uv build backend'),
  Option(
      name: '-b',
      description:
          'Constrain build dependencies using the given requirements files when building distributions',
      args: [Arg(name: 'BUILD_CONSTRAINTS')]),
  Option(
      name: '--require-hashes',
      description: 'Require a matching hash for each requirement'),
  Option(
      name: '--no-verify-hashes',
      description: 'Disable validation of hashes in the requirements file')
];