exportOptions top-level property

List<Option> exportOptions
final

Implementation

final List<Option> exportOptions = [
  Option(
      name: '--format',
      description: 'The format to which `uv.lock` should be exported',
      args: [Arg(name: 'FORMAT')]),
  Option(name: '--all-packages', description: 'Export the entire workspace'),
  Option(
      name: '--package',
      description:
          'Export the dependencies for a specific package in the workspace',
      args: [Arg(name: 'PACKAGE')]),
  Option(
      name: '--prune',
      description: 'Prune the given package from the dependency tree',
      args: [Arg(name: 'PRUNE')]),
  Option(
      name: '--extra',
      description:
          'Include optional dependencies from the specified extra name',
      args: [Arg(name: 'EXTRA')]),
  Option(
      name: '--all-extras', description: 'Include all optional dependencies'),
  Option(
      name: '--no-extra',
      description:
          'Exclude the specified optional dependencies, if `--all-extras` is supplied',
      args: [Arg(name: 'NO_EXTRA')]),
  Option(
      name: '--no-dev', description: 'Omit the development dependency group'),
  Option(
      name: '--only-dev',
      description: 'Only include the development dependency group'),
  Option(
      name: '--group',
      description: 'Include dependencies from the specified dependency group',
      args: [Arg(name: 'GROUP')]),
  Option(
      name: '--no-group',
      description: 'Exclude dependencies from the specified dependency group',
      args: [Arg(name: 'NO_GROUP')]),
  Option(
      name: '--only-group',
      description:
          'Only include dependencies from the specified dependency group',
      args: [Arg(name: 'ONLY_GROUP')]),
  Option(
      name: '--all-groups',
      description: 'Include dependencies from all dependency groups'),
  Option(
      name: '--no-header',
      description:
          'Exclude the comment header at the top of the generated output file'),
  Option(
      name: '--no-editable',
      description:
          'Install any editable dependencies, including the project and any workspace members, as non-editable'),
  Option(
      name: '--no-hashes', description: 'Omit hashes in the generated output'),
  Option(
      name: '-o',
      description: 'Write the exported requirements to the given file',
      args: [Arg(name: 'OUTPUT_FILE')]),
  Option(
      name: '--no-emit-project',
      description: 'Do not emit the current project'),
  Option(
      name: '--no-emit-workspace',
      description:
          'Do not emit any workspace members, including the root project'),
  Option(
      name: '--no-emit-package',
      description: 'Do not emit the given package(s)',
      args: [Arg(name: 'NO_EMIT_PACKAGE')]),
  Option(
      name: '--locked',
      description: 'Assert that the `uv.lock` will remain unchanged',
      args: [Arg(name: 'UV_LOCKED')]),
  Option(
      name: '--frozen',
      description: 'Do not update the `uv.lock` before exporting',
      args: [Arg(name: 'UV_FROZEN')])
];