indexOptions top-level property

List<Option> indexOptions
final

Implementation

final List<Option> indexOptions = [
  Option(
      name: '--index',
      description:
          'The URLs to use when resolving dependencies, in addition to the default index',
      args: [Arg(name: 'INDEX')]),
  Option(
      name: '--default-index',
      description:
          'The URL of the default package index (by default: <https://pypi.org/simple>)',
      args: [Arg(name: 'DEFAULT_INDEX')]),
  Option(
      name: '--index-url',
      description:
          'The URL of the Python package index (by default: <https://pypi.org/simple>)',
      args: [Arg(name: 'INDEX_URL')]),
  Option(
      name: '--extra-index-url',
      description:
          'Extra URLs of package indexes to use, in addition to `--index-url`',
      args: [Arg(name: 'EXTRA_INDEX_URL')]),
  Option(
      name: '--find-links',
      description:
          'Locations to search for candidate distributions, in addition to those found in the registry indexes',
      args: [Arg(name: 'FIND_LINKS')]),
  Option(
      name: '--no-index',
      description:
          'Ignore the registry index (e.g., PyPI), instead relying on direct URL dependencies and those provided via `--find-links`'),
  Option(
      name: '--index-strategy',
      description:
          'The strategy to use when resolving against multiple index URLs',
      args: [
        Arg(name: 'INDEX_STRATEGY', suggestions: [
          FigSuggestion(name: 'first-index'),
          FigSuggestion(name: 'unsafe-first-match'),
          FigSuggestion(name: 'unsafe-best-match')
        ])
      ]),
  Option(
      name: '--keyring-provider',
      description: 'Attempt to use `keyring` for authentication for index URLs',
      args: [
        Arg(name: 'KEYRING_PROVIDER', suggestions: [
          FigSuggestion(name: 'disabled'),
          FigSuggestion(name: 'subprocess')
        ])
      ])
];