initCacheOptions top-level property

List<Option> initCacheOptions
final

Implementation

final List<Option> initCacheOptions = [
  Option(
      name: '-n',
      description:
          'Avoid reading from or writing to the cache, instead using a temporary directory for the duration of the operation'),
  Option(
      name: '--cache-dir',
      description: 'Path to the cache directory',
      args: [Arg(name: 'CACHE_DIR')])
];