resolverOptions top-level property
Implementation
final List<Option> resolverOptions = [
Option(
name: '-U',
description:
'Allow package upgrades, ignoring pinned versions in any existing output file. Implies `--refresh`'),
Option(
name: '--upgrade-package',
description:
'Allow upgrades for a specific package, ignoring pinned versions in any existing output file. Implies `--refresh-package`',
args: [Arg(name: 'UPGRADE_PACKAGE')]),
Option(
name: '--resolution',
description:
'The strategy to use when selecting between the different compatible versions for a given package requirement',
args: [
Arg(name: 'RESOLUTION', suggestions: [
FigSuggestion(name: 'highest'),
FigSuggestion(name: 'lowest'),
FigSuggestion(name: 'lowest-direct')
])
]),
Option(
name: '--prerelease',
description: 'The strategy to use when considering pre-release versions',
args: [
Arg(name: 'PRERELEASE', suggestions: [
FigSuggestion(name: 'disallow'),
FigSuggestion(name: 'allow'),
FigSuggestion(name: 'if-necessary'),
FigSuggestion(name: 'explicit'),
FigSuggestion(name: 'if-necessary-or-explicit')
])
]),
Option(
name: '--exclude-newer',
description:
'Limit candidate packages to those that were uploaded prior to the given date',
args: [Arg(name: 'EXCLUDE_NEWER')]),
Option(
name: '--no-sources',
description:
'Ignore the `tool.uv.sources` table when resolving dependencies. Used to lock against the standards-compliant, publishable package metadata, as opposed to using any local or Git sources')
];