selfSubcommands top-level property

List<FigSubcommand> selfSubcommands
final

Implementation

final List<FigSubcommand> selfSubcommands = [
  Subcommand(name: 'update', description: 'Update uv', args: [
    Arg(
        name: 'TARGET_VERSION',
        description:
            'Update to the specified version. If not provided, uv will update to the latest version')
  ], options: [
    Option(
        name: '--token',
        description:
            'A GitHub token for authentication. A token is not required but can be used to reduce the chance of encountering rate limits [env:UV_GITHUB_TOKEN=]')
  ])
];