toolSubcommands top-level property

List<FigSubcommand> toolSubcommands
final

Implementation

final List<FigSubcommand> toolSubcommands = [
  Subcommand(
      name: 'run',
      description: 'Run a command provided by a Python package',
      options: [
        Option(
            name: '--from',
            description: 'Use the given package to provide the command',
            args: [Arg(name: 'FROM')]),
        Option(
            name: '--with',
            description: 'Run with the given packages installed',
            args: [Arg(name: 'WITH')]),
        Option(
            name: '--with-editable',
            description: 'Run with the given packages installed as editables',
            args: [Arg(name: 'WITH_EDITABLE')]),
        Option(
            name: '--with-requirements',
            description:
                'Run with all packages listed in the given `requirements.txt` files',
            args: [Arg(name: 'WITH_REQUIREMENTS')]),
        Option(
            name: '--isolated',
            description: 'Run the tool in an isolated virtual environment')
      ]),
  Subcommand(
      name: 'install',
      description: 'Install commands provided by a Python package',
      options: [
        Option(
            name: '--editable',
            description: 'Install the package in editable mode'),
        Option(
            name: '--with',
            description: 'Include the following extra requirements',
            args: [Arg(name: 'WITH')]),
        Option(
            name: '--with-editable',
            description: 'Include the given packages as editables',
            args: [Arg(name: 'WITH_EDITABLE')]),
        Option(
            name: '--with-requirements',
            description:
                'Run all requirements listed in the given `requirements.txt` files',
            args: [Arg(name: 'WITH_REQUIREMENTS')]),
        Option(
            name: '--isolated',
            description: 'Install the tool in an isolated virtual environment')
      ]),
  Subcommand(
      name: 'upgrade',
      description: 'Upgrade installed tools',
      options: [Option(name: '--all', description: 'Upgrade all tools')]),
  Subcommand(name: 'list', description: 'List installed tools', options: [
    Option(
        name: '--show-paths',
        description:
            'Whether to display the path to each tool environment and installed executable'),
    Option(
        name: '--show-version-specifiers',
        description:
            'Whether to display the version specifier(s) used to install each tool')
  ]),
  Subcommand(
      name: 'uninstall',
      description: 'Uninstall a tool',
      options: [Option(name: '--all', description: 'Uninstall all tools')]),
  Subcommand(
      name: 'update-shell',
      description:
          'Ensure that the tool executable directory is on the `PATH`'),
  Subcommand(
      name: 'dir',
      description: 'Show the path to the uv tools directory',
      options: [
        Option(
            name: '--bin',
            description:
                'Show the directory into which `uv tool` will install executables')
      ])
];