treeOptions top-level property

List<Option> treeOptions
final

Implementation

final List<Option> treeOptions = [
  Option(
      name: '--universal',
      description: 'Show a platform-independent dependency tree'),
  Option(
      name: '-d',
      description: 'Maximum display depth of the dependency tree',
      args: [Arg(name: 'DEPTH', defaultValue: '255')]),
  Option(
      name: '--prune',
      description:
          'Prune the given package from the display of the dependency tree',
      args: [Arg(name: 'PRUNE')]),
  Option(
      name: '--package',
      description: 'Display only the specified packages',
      args: [Arg(name: 'PACKAGE')]),
  Option(
      name: '--no-dedupe',
      description:
          'Do not de-duplicate repeated dependencies. Usually, when a package has already displayed its dependencies, further occurrences will not re-display its dependencies, and will include a (*) to indicate it has already been shown. This flag will cause those duplicates to be repeated'),
  Option(
      name: '--invert',
      description:
          'Show the reverse dependencies for the given package. This flag will invert the tree and display the packages that depend on the given package'),
  Option(
      name: '--outdated',
      description:
          'Show the latest available version of each package in the tree'),
  Option(
      name: '--only-dev',
      description: 'Only include the development dependency group'),
  Option(
      name: '--no-dev', description: 'Omit the development dependency group'),
  Option(
      name: '--group',
      description: 'Include dependencies from the specified dependency group',
      args: [Arg(name: 'GROUP')]),
  Option(
      name: '--no-group',
      description: 'Exclude dependencies from the specified dependency group',
      args: [Arg(name: 'NO_GROUP')]),
  Option(
      name: '--only-group',
      description:
          'Only include dependencies from the specified dependency group',
      args: [Arg(name: 'ONLY_GROUP')]),
  Option(
      name: '--all-groups',
      description: 'Include dependencies from all dependency groups'),
  Option(
      name: '--locked',
      description: 'Assert that the `uv.lock` will remain unchanged',
      args: [Arg(name: 'UV_LOCKED')]),
  Option(
      name: '--frozen',
      description: 'Display the requirements without locking the project',
      args: [Arg(name: 'UV_FROZEN')]),
  Option(
      name: '--python-version',
      description: 'The Python version to use when filtering the tree',
      args: [Arg(name: 'PYTHON_VERSION')]),
  Option(
      name: '--python-platform',
      description: 'The platform to use when filtering the tree',
      args: [
        Arg(name: 'PYTHON_PLATFORM', suggestions: [
          FigSuggestion(name: 'windows'),
          FigSuggestion(name: 'linux'),
          FigSuggestion(name: 'macos'),
          FigSuggestion(name: 'x86_64-pc-windows-msvc'),
          FigSuggestion(name: 'i686-pc-windows-msvc'),
          FigSuggestion(name: 'x86_64-unknown-linux-gnu'),
          FigSuggestion(name: 'aarch64-apple-darwin'),
          FigSuggestion(name: 'x86_64-apple-darwin'),
          FigSuggestion(name: 'aarch64-unknown-linux-gnu'),
          FigSuggestion(name: 'aarch64-unknown-linux-musl'),
          FigSuggestion(name: 'x86_64-unknown-linux-musl'),
          FigSuggestion(name: 'x86_64-manylinux_2_17'),
          FigSuggestion(name: 'x86_64-manylinux_2_28'),
          FigSuggestion(name: 'x86_64-manylinux_2_31'),
          FigSuggestion(name: 'x86_64-manylinux_2_32'),
          FigSuggestion(name: 'x86_64-manylinux_2_33'),
          FigSuggestion(name: 'x86_64-manylinux_2_34'),
          FigSuggestion(name: 'x86_64-manylinux_2_35'),
          FigSuggestion(name: 'x86_64-manylinux_2_36'),
          FigSuggestion(name: 'x86_64-manylinux_2_37'),
          FigSuggestion(name: 'x86_64-manylinux_2_38'),
          FigSuggestion(name: 'x86_64-manylinux_2_39'),
          FigSuggestion(name: 'x86_64-manylinux_2_40'),
          FigSuggestion(name: 'aarch64-manylinux_2_17'),
          FigSuggestion(name: 'aarch64-manylinux_2_28'),
          FigSuggestion(name: 'aarch64-manylinux_2_31'),
          FigSuggestion(name: 'aarch64-manylinux_2_32'),
          FigSuggestion(name: 'aarch64-manylinux_2_33'),
          FigSuggestion(name: 'aarch64-manylinux_2_34'),
          FigSuggestion(name: 'aarch64-manylinux_2_35'),
          FigSuggestion(name: 'aarch64-manylinux_2_36'),
          FigSuggestion(name: 'aarch64-manylinux_2_37'),
          FigSuggestion(name: 'aarch64-manylinux_2_38'),
          FigSuggestion(name: 'aarch64-manylinux_2_39'),
          FigSuggestion(name: 'aarch64-manylinux_2_40')
        ])
      ])
];