venvOptions top-level property

List<Option> venvOptions
final

Implementation

final List<Option> venvOptions = [
  Option(
      name: '--no-project',
      description: 'Avoid discovering a project or workspace'),
  Option(
      name: '--seed',
      description:
          'Install seed packages (one or more of: `pip`, `setuptools`, and `wheel`) into the virtual environment'),
  Option(
      name: '--allow-existing',
      description:
          'Preserve any existing files or directories at the target path'),
  Option(
      name: '--prompt',
      description:
          'Provide an alternative prompt prefix for the virtual environment',
      args: [Arg(name: 'PROMPT')]),
  Option(
      name: '--system-site-packages',
      description:
          'Give the virtual environment access to the system site packages directory'),
  Option(
      name: '--relocatable',
      description: 'Make the virtual environment relocatable'),
  Option(
      name: '--index-strategy',
      description:
          'The strategy to use when resolving against multiple index URLs',
      args: [
        Arg(name: 'INDEX_STRATEGY', suggestions: [
          FigSuggestion(name: 'first-index'),
          FigSuggestion(name: 'unsafe-first-match'),
          FigSuggestion(name: 'unsafe-best-match')
        ])
      ]),
  Option(
      name: '--keyring-provider',
      description: 'Attempt to use `keyring` for authentication for index URLs',
      args: [
        Arg(name: 'KEYRING_PROVIDER', suggestions: [
          FigSuggestion(name: 'disabled'),
          FigSuggestion(name: 'subprocess')
        ])
      ]),
  Option(
      name: '--exclude-newer',
      description:
          'Limit candidate packages to those that were uploaded prior to the given date',
      args: [Arg(name: 'EXCLUDE_NEWER')]),
  Option(
      name: '--link-mode',
      description:
          'The method to use when installing packages from the global cache',
      args: [
        Arg(name: 'LINK_MODE', suggestions: [
          FigSuggestion(name: 'clone'),
          FigSuggestion(name: 'copy'),
          FigSuggestion(name: 'hardlink'),
          FigSuggestion(name: 'symlink')
        ])
      ])
];