vaultAgentOptions top-level property
Implementation
final List<Option> vaultAgentOptions = [
Option(
name: '-config',
description: 'Path to a configuration file. This configuration file should contain only agent directives',
args: [
Arg(
name: 'string',
template: 'filepaths'
)
],
priority: 38
),
Option(
name: '-exit-after-auth',
description: 'If set to true, the agent will exit with code 0 after a single successful auth, where success means that a token was retrieved and all sinks successfully wrote it The default is false',
args: [
Arg(
name: 'string',
suggestions: [
FigSuggestion(name: 'false'),
FigSuggestion(name: 'true')
],
defaultValue: 'false'
)
],
priority: 38
),
Option(
name: '-log-level',
description: 'Log verbosity level. Supported values (in order of detail) are \'trace\', \'debug\', \'info\', \'warn\', and \'err\'. The default is info. This can also be specified via the VAULT_LOG_LEVEL environment variable',
args: [
Arg(
name: 'string',
suggestions: [
FigSuggestion(name: 'trace'),
FigSuggestion(name: 'debug'),
FigSuggestion(name: 'info'),
FigSuggestion(name: 'warn'),
FigSuggestion(name: 'err')
],
defaultValue: 'info'
)
],
priority: 38
)
];