vaultKvPatchOptions top-level property

List<Option> vaultKvPatchOptions
final

Implementation

final List<Option> vaultKvPatchOptions = [

  Option(
    name: '-cas',
    description: 'Specifies to use a Check-And-Set operation. If set to 0 or not set, the patch will be allowed. If the index is non-zero the patch will only be allowed if the key’s current version matches the version specified in the cas parameter',
    args: [
      Arg(
      name: 'int',
      suggestions: [

        FigSuggestion(name: '-1'),
        FigSuggestion(name: '0'),
        FigSuggestion(name: '1')
      ],
      defaultValue: '-1'
    )
    ],
    priority: 38
  ),
  Option(
    name: '-method',
    description: 'Specifies which method of patching to use. If set to \'patch\', then an HTTP PATCH request will be issued. If set to \'rw\', then a read will be performed, then a local update, followed by a remote update',
    args: [
      Arg(
      name: 'string',
      suggestions: [

        FigSuggestion(name: 'patch'),
        FigSuggestion(name: 'rw')
      ]
    )
    ],
    priority: 38
  )
];