vaultKvPutOptions top-level property
Implementation
final List<Option> vaultKvPutOptions = [
Option(
name: '-cas',
description: 'Specifies to use a Check-And-Set operation. If set to 0 or not set, the patch will be allowed. If the index is non-zero the patch will only be allowed if the key’s current version matches the version specified in the cas parameter',
args: [
Arg(
name: 'int',
suggestions: [
FigSuggestion(name: '-1'),
FigSuggestion(name: '0'),
FigSuggestion(name: '1')
],
defaultValue: '-1'
)
],
priority: 38
)
];