vaultLoginOptions top-level property
Implementation
final List<Option> vaultLoginOptions = [
Option(
name: '-method',
description: 'Type of authentication to use such as \'userpass\' or \'ldap\'. Note this corresponds to the TYPE, not the enabled path. Use -path to specify the path where the authentication is enabled. The default is token',
args: [
Arg(
name: 'string',
suggestions: [
FigSuggestion(name: 'userpass'),
FigSuggestion(name: 'ldap'),
FigSuggestion(name: 'token')
],
defaultValue: 'token'
)
],
priority: 38
),
Option(
name: '-no-print',
description: 'Do not display the token. The token will be still be stored to the configured token helper. The default is false',
args: [
Arg(
name: 'string',
suggestions: [
FigSuggestion(name: 'false'),
FigSuggestion(name: 'true')
],
defaultValue: 'false'
)
],
priority: 38
),
Option(
name: '-no-store',
description: 'Do not persist the token to the token helper (usually the local filesystem) after authentication for use in future requests. The token will only be displayed in the command output. The default is false',
args: [
Arg(
name: 'string',
suggestions: [
FigSuggestion(name: 'false'),
FigSuggestion(name: 'true')
],
defaultValue: 'false'
)
],
priority: 38
),
Option(
name: '-path',
description: 'Remote path in Vault where the auth method is enabled. This defaults to the TYPE of method (e.g. userpass -> userpass/)',
args: [
Arg(
name: 'string',
suggestions: [
FigSuggestion(name: 'userpass/')
],
defaultValue: 'userpass/'
)
],
priority: 38
),
Option(
name: '-token-only',
description: 'Output only the token with no verification. This flag is a shortcut for \'-field=token -no-store\'. Setting those flags to other values will have no affect. The default is false',
args: [
Arg(
name: 'string',
suggestions: [
FigSuggestion(name: 'false'),
FigSuggestion(name: 'true')
],
defaultValue: 'false'
)
],
priority: 38
)
];