vaultOperatorConsulOptions top-level property
Implementation
final List<Option> vaultOperatorConsulOptions = [
Option(
name: '-consul-auto',
description: 'Perform automatic service discovery using Consul in HA mode. When all nodes in a Vault HA cluster are registered with Consul, enabling this option will trigger automatic service discovery based on the provided -consul-service value. When Consul is Vault\'s HA backend, this functionality is automatically enabled. Ensure the proper Consul environment variables are set (CONSUL_HTTP_ADDR, etc). When only one Vault server is discovered, it will be initialized automatically. When more than one Vault server is discovered, they will each be output for selection. The default is false'
),
Option(
name: '-consul-service',
description: 'Name of the service in Consul under which the Vault servers are registered. The default is vault',
args: [
Arg(
name: 'string',
suggestions: [
FigSuggestion(name: 'vault')
],
defaultValue: 'vault'
)
]
)
];