vaultOperatorGenerateRootOptions top-level property

List<Option> vaultOperatorGenerateRootOptions
final

Implementation

final List<Option> vaultOperatorGenerateRootOptions = [

  Option(
    name: '-cancel',
    description: 'Reset the root token generation progress. This will discard any submitted unseal keys or configuration. The default is false'
  ),
  Option(
    name: '-decode',
    description: 'The value to decode; setting this triggers a decode operation. If the value is \'-\' then read the encoded token from stdin',
    args: [
      Arg(
      name: 'string',
      suggestions: [

        FigSuggestion(name: '-')
      ],
      defaultValue: '-'
    )
    ],
    priority: 38
  ),
  Option(
    name: '-dr-token',
    description: 'Set this flag to do generate root operations on DR Operational tokens. The default is false'
  ),
  Option(
    name: '-generate-otp',
    description: 'Generate and print a high-entropy one-time-password (OTP) suitable for use with the \'-init\' flag. The default is false'
  ),
  Option(
    name: '-init',
    description: 'Start a root token generation. This can only be done if there is not currently one in progress. The default is false'
  ),
  Option(
    name: '-nonce',
    description: 'Nonce value provided at initialization. The same nonce value must be provided with each unseal key',
    args: [
      Arg(
      name: 'string'
    )
    ],
    priority: 38
  ),
  Option(
    name: '-otp',
    description: 'OTP code to use with \'-decode\' or \'-init\'',
    args: [
      Arg(
      name: 'string'
    )
    ],
    priority: 38
  ),
  Option(
    name: '-pgp-key',
    description: 'Path to a file on disk containing a binary or base64-encoded public PGP key. This can also be specified as a Keybase username using the format \'keybase:<username>\'. When supplied, the generated root token will be encrypted and base64-encoded with the given public key',
    args: [

      Arg(
        name: 'string',
        template: 'filepaths'
      ),
      Arg(
        name: 'keybase:user'
      )
    ],
    priority: 38
  ),
  Option(
    name: '-recovery-token',
    description: 'Set this flag to do generate root operations on Recovery Operational tokens. The default is false'
  ),
  Option(
    name: '-status',
    description: 'Print the status of the current attempt without providing an unseal key. The default is false'
  )
];