vaultOperatorRaftJoinOptions top-level property
Implementation
final List<Option> vaultOperatorRaftJoinOptions = [
Option(
name: '-auto-join-port',
description: 'An optional port used for addresses discovered via auto-join. The default is 8200',
args: [
Arg(
name: 'uint',
suggestions: [
FigSuggestion(name: '8200')
],
defaultValue: '8200'
)
]
),
Option(
name: '-auto-join-scheme',
description: 'An optional URI protocol scheme used for addresses discovered via auto-join. The default is https',
args: [
Arg(
name: 'string',
suggestions: [
FigSuggestion(name: 'https'),
FigSuggestion(name: 'http')
],
defaultValue: 'https'
)
]
),
Option(
name: '-leader-ca-cert',
description: 'CA cert to use when verifying the Raft leader certificate',
args: [
Arg(
name: 'string',
suggestions: [
FigSuggestion(name: '@/path/to/leader_ca.crt')
],
template: 'filepaths'
)
]
),
Option(
name: '-leader-client-cert',
description: 'Client cert to use when authenticating with the Raft leader',
args: [
Arg(
name: 'string',
suggestions: [
FigSuggestion(name: '@/path/to/client.crt')
],
template: 'filepaths'
)
]
),
Option(
name: '-leader-client-key',
description: 'Client key to use when authenticating with the Raft leader',
args: [
Arg(
name: 'string',
suggestions: [
FigSuggestion(name: '@/path/to/client.key')
],
template: 'filepaths'
)
]
),
Option(
name: '-non-voter',
description: '(Enterprise-only) This flag is used to make the server not participate in the Raft quorum, and have it only receive the data replication stream. This can be used to add read scalability to a cluster in cases where a high volume of reads to servers are needed. The default is false'
),
Option(
name: '-retry',
description: 'Continuously retry joining the Raft cluster upon failures. The default is false'
)
];