vaultOperatorUnsealOptions top-level property

List<Option> vaultOperatorUnsealOptions
final

Implementation

final List<Option> vaultOperatorUnsealOptions = [

  Option(
    name: '-migrate',
    description: 'Indicate that this share is provided with the intent that it is part of a seal migration process. The default is false'
  ),
  Option(
    name: '-reset',
    description: 'Discard any previously entered keys to the unseal process. The default is false'
  )
];