vaultOutputFieldOptions top-level property

List<Option> vaultOutputFieldOptions
final

Implementation

final List<Option> vaultOutputFieldOptions = [

  Option(
    name: '-field',
    description: 'Print only the field with the given name. Specifying this option will take precedence over other formatting directives. The result will not have a trailing newline making it ideal for piping to other processes',
    args: [
      Arg(
      name: 'string'
    )
    ],
    priority: 39
  )
];