vaultSecretsEnableOptions top-level property
Implementation
final List<Option> vaultSecretsEnableOptions = [
Option(
name: '-allowed-managed-keys',
description: 'Managed key name(s) that the mount in question is allowed to access. Note that multiple keys may be specified by providing this option multiple times, each time with 1 key',
args: [
Arg(
name: 'string'
)
]
),
Option(
name: '-allowed-response-headers',
description: 'Comma-separated string or list of response header values that plugins will be allowed to set',
args: [
Arg(
name: 'string'
)
]
),
Option(
name: '-audit-non-hmac-request-keys',
description: 'Comma-separated string or list of keys that will not be HMAC\'d by audit devices in the request data object',
args: [
Arg(
name: 'string'
)
]
),
Option(
name: '-audit-non-hmac-response-keys',
description: 'Comma-separated string or list of keys that will not be HMAC\'d by audit devices in the response data object',
args: [
Arg(
name: 'string'
)
]
),
Option(
name: '-default-lease-ttl',
description: 'The default lease TTL for this secrets engine. If unspecified, this defaults to the Vault server\'s globally configured default lease TTL',
args: [
Arg(
name: 'duration'
)
]
),
Option(
name: '-description',
description: 'Human-friendly description for the purpose of this engine',
args: [
Arg(
name: 'string'
)
]
),
Option(
name: '-external-entropy-access',
description: 'Enable secrets engine to access Vault\'s external entropy source. The default is false'
),
Option(
name: '-force-no-cache',
description: 'Force the secrets engine to disable caching. If unspecified, this defaults to the Vault server\'s globally configured cache settings. This does not affect caching of the underlying encrypted data storage. The default is false'
),
Option(
name: '-listing-visibility',
description: 'Determines the visibility of the mount in the UI-specific listing endpoint',
args: [
Arg(
name: 'string'
)
]
),
Option(
name: '-local',
description: 'Mark the secrets engine as local-only. Local engines are not replicated or removed by replication. The default is false'
),
Option(
name: '-max-lease-ttl',
description: 'The maximum lease TTL for this secrets engine. If unspecified, this defaults to the Vault server\'s globally configured maximum lease TTL',
args: [
Arg(
name: 'duration'
)
]
),
Option(
name: '-options',
description: 'Key-value pair provided as key=value for the mount options. This can be specified multiple times',
args: [
Arg(
name: 'key=value'
)
]
),
Option(
name: '-passthrough-request-headers',
description: 'Comma-separated string or list of request header values that will be sent to the plugins',
args: [
Arg(
name: 'string'
)
]
),
Option(
name: '-path',
description: 'Place where the secrets engine will be accessible. This must be unique cross all secrets engines. This defaults to the \'type\' of the secrets engine',
args: [
Arg(
name: 'string'
)
]
),
Option(
name: '-plugin-name',
description: 'Name of the secrets engine plugin. This plugin name must already exist in Vault\'s plugin catalog',
args: [
Arg(
name: 'string'
)
]
),
Option(
name: '-seal-wrap',
description: 'Enable seal wrapping of critical values in the secrets engine. The default is false'
),
Option(
name: '-version',
description: 'Select the version of the engine to run. Not supported by all engines',
args: [
Arg(
name: 'int'
)
]
)
];