vaultServerOptions top-level property

List<Option> vaultServerOptions
final

Implementation

final List<Option> vaultServerOptions = [

  Option(
    name: '-config',
    description: 'Path to a configuration file or directory of configuration files. This flag can be specified multiple times to load multiple configurations.  If the path is a directory, all files which end in .hcl or .json are loaded',
    args: [
      Arg(
      name: 'string',
      template: 'filepaths'
    )
    ],
    priority: 38
  ),
  Option(
    name: '-exit-on-core-shutdown',
    description: 'Exit the vault server if the vault core is shutdown. The default is false',
    args: [
      Arg(
      name: 'string',
      suggestions: [

        FigSuggestion(name: 'false'),
        FigSuggestion(name: 'true')
      ],
      defaultValue: 'false'
    )
    ],
    priority: 38
  ),
  Option(
    name: '-log-format',
    description: 'Log format. Supported values are \'standard\' and \'json\'. The default is (not set)',
    args: [
      Arg(
      name: 'string',
      suggestions: [

        FigSuggestion(name: 'standard'),
        FigSuggestion(name: 'json')
      ]
    )
    ],
    priority: 38
  ),
  Option(
    name: '-log-level',
    description: 'Log verbosity level. Supported values (in order of detail) are \'trace\', \'debug\', \'info\', \'warn\', and \'err\'. The default is info. This can also be specified via the VAULT_LOG_LEVEL environment variable',
    args: [
      Arg(
      name: 'string',
      suggestions: [

        FigSuggestion(name: 'trace'),
        FigSuggestion(name: 'debug'),
        FigSuggestion(name: 'info'),
        FigSuggestion(name: 'warn'),
        FigSuggestion(name: 'err')
      ],
      defaultValue: 'info'
    )
    ],
    priority: 38
  ),
  Option(
    name: '-recovery',
    description: 'Enable recovery mode. In this mode, Vault is used to perform recovery actions.Using a recovery operation token, \'sys/raw\' API can be used to manipulate the storage. The default is false',
    args: [
      Arg(
      name: 'string',
      suggestions: [

        FigSuggestion(name: 'false'),
        FigSuggestion(name: 'true')
      ],
      defaultValue: 'false'
    )
    ],
    priority: 38
  )
];