vaultSshCaOptions top-level property
Implementation
final List<Option> vaultSshCaOptions = [
Option(
name: '-host-key-hostnames',
description: 'List of hostnames to delegate for the CA. The default value allows all domains and IPs. This is specified as a comma-separated list of values. The default is *. This can also be specified via the VAULT_SSH_HOST_KEY_HOSTNAMES environment variable',
args: [
Arg(
name: 'string',
suggestions: [
FigSuggestion(name: '*')
],
defaultValue: '*'
)
]
),
Option(
name: '-host-key-mount-point',
description: 'Mount point to the SSH secrets engine where host keys are signed. When given a value, Vault will generate a custom \'known_hosts\' file with delegation to the CA at the provided mount point to verify the SSH connection\'s host keys against the provided CA. By default, host keys are validated against the user\'s local \'known_hosts\' file. This flag forces strict key host checking and ignores a custom user known hosts file. This can also be specified via the VAULT_SSH_HOST_KEY_MOUNT_POINT environment variable',
args: [
Arg(
name: 'string',
template: 'folders'
)
]
),
Option(
name: '-private-key-path',
description: 'Path to the SSH private key to use for authentication. This must be the corresponding private key to -public-key-path. The default is ~/.ssh/id_rsa',
args: [
Arg(
name: 'string',
suggestions: [
FigSuggestion(name: '~/.ssh/id_rsa')
],
defaultValue: '~/.ssh/id_rsa',
template: 'filepaths'
)
]
),
Option(
name: '-public-key-path',
description: 'Path to the SSH public key to send to Vault for signing. The default is ~/.ssh/id_rsa.pub',
args: [
Arg(
name: 'string',
suggestions: [
FigSuggestion(name: '~/.ssh/id_rsa.pub')
],
defaultValue: '~/.ssh/id_rsa.pub',
template: 'filepaths'
)
]
),
Option(
name: '-ssh-executable',
description: 'Path to the SSH executable to use when connecting to the host The default is ssh. This can also be specified via the VAULT_SSH_EXECUTABLE environment variable',
args: [
Arg(
name: 'string',
suggestions: [
FigSuggestion(name: 'ssh'),
FigSuggestion(name: '/usr/bin/ssh')
],
defaultValue: 'ssh',
template: 'filepaths'
)
]
),
Option(
name: '-valid-principals',
description: 'List of valid principal names to include in the generated user certificate. This is specified as a comma-separated list of values',
args: [
Arg(
name: 'string'
)
]
)
];