vaultSshOptions top-level property
Implementation
final List<Option> vaultSshOptions = [
Option(
name: '-mode',
description: 'Name of the authentication mode (ca, dynamic, otp)',
args: [
Arg(
name: 'string',
suggestions: [
FigSuggestion(name: 'ca'),
FigSuggestion(name: 'dynamic'),
FigSuggestion(name: 'otp')
]
)
]
),
Option(
name: '-mount-point',
description: 'Mount point to the SSH secrets engine. The default is ssh/',
args: [
Arg(
name: 'string',
suggestions: [
FigSuggestion(name: 'ssh/')
],
defaultValue: 'ssh/'
)
]
),
Option(
name: '-no-exec',
description: 'Print the generated credentials, but do not establish a connection. The default is false'
),
Option(
name: '-role',
description: 'Name of the role to use to generate the key',
args: [
Arg(
name: 'string'
)
]
),
Option(
name: '-strict-host-key-checking',
description: 'Value to use for the SSH configuration option \'StrictHostKeyChecking\'. The default is ask. This can also be specified via the VAULT_SSH_STRICT_HOST_KEY_CHECKING environment variable',
args: [
Arg(
name: 'string'
)
]
),
Option(
name: '-user-known-hosts-file',
description: 'Value to use for the SSH configuration option \'UserKnownHostsFile\'. This can also be specified via the VAULT_SSH_USER_KNOWN_HOSTS_FILE environment variable',
args: [
Arg(
name: 'string',
suggestions: [
FigSuggestion(name: '~/.ssh/known_hosts')
],
defaultValue: '~/.ssh/known_hosts',
template: 'filepaths'
)
]
)
];