vaultTokenCreateOptions top-level property

List<Option> vaultTokenCreateOptions
final

Implementation

final List<Option> vaultTokenCreateOptions = [

  Option(
    name: '-display-name',
    description: 'Name to associate with this token. This is a non-sensitive value that can be used to help identify created secrets (e.g. prefixes)',
    args: [
      Arg(
      name: 'string'
    )
    ]
  ),
  Option(
    name: '-empty-alias',
    description: 'Name of the entity alias to associate with during token creation. Only works in combination with -role argument and used entity alias must be listed in allowed_entity_aliases. If this has been specified, the entity will not be inherited from the parent',
    args: [
      Arg(
      name: 'string'
    )
    ]
  ),
  Option(
    name: '-explicit-max-ttl',
    description: 'Explicit maximum lifetime for the token. Unlike normal TTLs, the maximum TTL is a hard limit and cannot be exceeded. This is specified as a numeric string with suffix like \'30s\' or \'5m\'',
    args: [
      Arg(
      name: 'duration',
      suggestions: [

        FigSuggestion(name: '30s'),
        FigSuggestion(name: '1m'),
        FigSuggestion(name: '5m')
      ]
    )
    ]
  ),
  Option(
    name: '-id',
    description: 'Value for the token. By default, this is an auto-generated string. Specifying this value requires sudo permissions',
    args: [
      Arg(
      name: 'string'
    )
    ]
  ),
  Option(
    name: '-metadata',
    description: 'Arbitrary key=value metadata to associate with the token. This metadata will show in the audit log when the token is used. This can be specified multiple times to add multiple pieces of metadata',
    args: [
      Arg(
      name: 'key=value'
    )
    ]
  ),
  Option(
    name: '-no-default-policy',
    description: 'Detach the \'default\' policy from the policy set for this token. The default is false'
  ),
  Option(
    name: '-orphan',
    description: 'Create the token with no parent. This prevents the token from being revoked when the token which created it expires. Setting this value requires root or sudo permissions. The default is false'
  ),
  Option(
    name: '-period',
    description: 'If specified, every renewal will use the given period. Periodic tokens do not expire (unless -explicit-max-ttl is also provided). Setting this value requires sudo permissions. This is specified as a numeric string with suffix like \'30s\' or \'5m\'',
    args: [
      Arg(
      name: 'duration',
      suggestions: [

        FigSuggestion(name: '30s'),
        FigSuggestion(name: '1m'),
        FigSuggestion(name: '5m')
      ]
    )
    ]
  ),
  Option(
    name: '-policy',
    description: 'Name of a policy to associate with this token. This can be specified multiple times to attach multiple policies',
    args: [
      Arg(
      name: 'string'
    )
    ]
  ),
  Option(
    name: '-renewable',
    description: 'Allow the token to be renewed up to it\'s maximum TTL. The default is true'
  ),
  Option(
    name: '-role',
    description: 'Name of the role to create the token against. Specifying -role may override other arguments. The locally authenticated Vault token must have permission for \'auth/token/create/<role>\'',
    args: [
      Arg(
      name: 'string'
    )
    ]
  ),
  Option(
    name: '-ttl',
    description: 'Initial TTL to associate with the token. Token renewals may be able to extend beyond this value, depending on the configured maximum TTLs. This is specified as a numeric string with suffix like \'30s\' or \'5m\'',
    args: [
      Arg(
      name: 'duration',
      suggestions: [

        FigSuggestion(name: '30s'),
        FigSuggestion(name: '1m'),
        FigSuggestion(name: '5m')
      ]
    )
    ]
  ),
  Option(
    name: '-type',
    description: 'The type of token to create. Can be \'service\' or \'batch\'. The default is service',
    args: [
      Arg(
      name: 'string',
      suggestions: [

        FigSuggestion(name: 'service'),
        FigSuggestion(name: 'batch')
      ],
      defaultValue: 'service'
    )
    ]
  ),
  Option(
    name: '-use-limit',
    description: 'Number of times this token can be used. After the last use, the token is automatically revoked. By default, tokens can be used an unlimited number of times until their expiration',
    args: [
      Arg(
      name: 'int'
    )
    ]
  )
];