vaultTokenLookupOptions top-level property

List<Option> vaultTokenLookupOptions
final

Implementation

final List<Option> vaultTokenLookupOptions = [

  Option(
    name: '-accessor',
    description: 'Treat the argument as an accessor instead of a token. When this option is selected, the output will NOT include the token. The default is false'
  )
];