vaultTokenRenewOptions top-level property

List<Option> vaultTokenRenewOptions
final

Implementation

final List<Option> vaultTokenRenewOptions = [

  Option(
    name: '-accessor',
    description: 'Treat the argument as an accessor instead of a token. When this option is selected, the output will NOT include the token. The default is false'
  ),
  Option(
    name: ['-increment', '-i'],
    description: 'Request a specific increment for renewal. This increment may not be honored, for instance in the case of periodic tokens. If not supplied, Vault will use the default TTL. This is specified as a numeric string with suffix like \'30s\' or \'5m\'. This is aliased as \'-i\'',
    args: [
      Arg(
      name: 'duration',
      suggestions: [

        FigSuggestion(name: '30s'),
        FigSuggestion(name: '1m'),
        FigSuggestion(name: '5m')
      ]
    )
    ]
  )
];