whenceSpec top-level property

FigSpec whenceSpec
final

Completion spec for whence CLI

Implementation

final FigSpec whenceSpec = FigSpec(
  name: 'whence',
  description: 'For each name, indicate how it should be interpreted',
  args: [
    Arg(
    name: 'names',
    isVariadic: true
  )
  ],
  options: [

    Option(
      name: '-v',
      description: 'Produce verbose output'
    ),
    Option(
      name: '-c',
      description: 'Print results in a csh-like format'
    ),
    Option(
      name: '-w',
      description: 'For each name, print \'name: word\', where \'word\' is the kind of command'
    ),
    Option(
      name: '-f',
      description: 'Display contents of shell functions'
    ),
    Option(
      name: '-p',
      description: 'Do a path search for the name, even if it\'s an alias/function/builtin'
    ),
    Option(
      name: '-a',
      description: 'Don\'t stop at the first match on the path'
    ),
    Option(
      name: '-m',
      description: 'The arguments are taken as patterns (pattern characters must be quoted)'
    ),
    Option(
      name: '-s',
      description: 'If the pathname contains symlinks, print the symlink-free name as well'
    ),
    Option(
      name: '-S',
      description: 'Print intermediate symlinks and the resolved name'
    ),
    Option(
      name: '-x',
      description: 'Expand tabs when outputting shell function',
      args: [
        Arg(
        name: 'nu'
      )
      ]
    )
  ]
);