FigSubcommand class
Subcommand (nested command). Extends BaseSuggestion in TS.
Constructors
-
FigSubcommand({required dynamic name, String? displayName, String? description, List<
FigSubcommand> ? subcommands, List<FigOption> ? options, dynamic args, String? icon, dynamic loadSpec, FilterStrategy? filterStrategy, int? priority, bool? requiresSubcommand, List? additionalSuggestions, FigGenerateSubcommandCallback? generateSpec, dynamic generateSpecCacheKey, dynamic parserDirectives, bool? cache, String? insertValue, String? replaceValue, bool? isDangerous, dynamic deprecated, })
Properties
- additionalSuggestions → List?
-
(string | Suggestion)[] in TS.
final
-
args
→ List<
FigArg> ? -
Positional argument(s) (TS/JS allows single object or array; Dart unified as list).
final
- cache → bool?
-
Whether to cache loadSpec/generateSpec result.
final
- deprecated → dynamic
-
final
- description → String?
-
final
- displayName → String?
-
final
- filterStrategy → FilterStrategy?
-
final
- generateSpec → FigGenerateSubcommandCallback?
-
Dynamically generate a subcommand at runtime (see FigGenerateSubcommandCallback). Not serialized to JSON.
final
- generateSpecCacheKey → dynamic
-
Function or string in TS.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
final
- icon → String?
-
final
- insertValue → String?
-
final
- isDangerous → bool?
-
final
- loadSpec → dynamic
-
String, Subcommand, or function (dynamic for TS compat).
final
- name → dynamic
-
final
-
nameList
→ List<
String> -
no setter
-
options
→ List<
FigOption> ? -
final
- parserDirectives → dynamic
-
{ flagsArePosixNoncompliant?, optionsMustPrecedeArguments?, optionArgSeparators? }
final
- priority → int?
-
final
- replaceValue → String?
-
final
- requiresSubcommand → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subcommands
→ List<
FigSubcommand> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited