applyOptions top-level property
Implementation
final List<Option> applyOptions = [
Option(
name: ['--path', '-p'],
description: 'Path to a sub-directory in which to look for a preset',
args: [
Arg(
name: 'path'
)
]
),
Option(
name: ['--tag', '-t'],
description: 'Branch or tag to use if the preset is a repository',
args: [
Arg(
name: 'tag'
)
]
),
Option(
name: '--no-ssh',
description: 'Do not use SSH when cloning repositories'
),
Option(
name: '--no-cache',
description: 'Do not use the cached repository if it exists'
)
];