collectionBuildOptions top-level property
Implementation
final List<Option> collectionBuildOptions = [
Option(
name: ['--force', '-f'],
description: 'Force overwriting an existing role or collection'
),
Option(
name: '--output-path',
description: 'The path in which the collection is built to',
args: [
Arg(
name: 'output_path',
description: 'The path in which the collection is built to',
template: ['folders'],
defaultValue: '.'
)
]
)
];