collectionListOptions top-level property
Implementation
final List<Option> collectionListOptions = [
Option(
name: ['--collections-path', '-p'],
description: 'One or more directories to search for collections in addition to the default COLLECTIONS_PATHS; separate multiple paths with \':\'',
args: [
Arg(
name: 'collections_path',
description: 'One or more directories to search for collections in addition to the default COLLECTIONS_PATHS; separate multiple paths with \':\'',
template: ['folders'],
suggestions: [
FigSuggestion(name: '~/.ansible/collections:/usr/share/ansible/collections')
],
defaultValue: '~/.ansible/collections:/usr/share/ansible/collections'
)
]
),
Option(
name: '--format',
description: 'Format to display the list of collections in',
args: [
Arg(
name: 'format',
description: 'Format to display the list of collections in',
suggestions: [
FigSuggestion(name: 'human'),
FigSuggestion(name: 'yaml'),
FigSuggestion(name: 'json')
],
defaultValue: 'human'
)
]
)
];