roleInstallOptions top-level property
Implementation
final List<Option> roleInstallOptions = [
Option(
name: ['--roles-path', '--role-path'],
description: 'The path to the directory containing your roles',
args: [
Arg(
name: 'roles_path',
description: 'The path to the directory containing your roles',
suggestions: [
FigSuggestion(name: '~/.ansible/roles:/usr/share/ansible/roles:/etc/ansible/roles')
],
defaultValue: '~/.ansible/roles:/usr/share/ansible/roles:/etc/ansible/roles'
)
]
),
Option(
name: ['--no-deps', '-n'],
description: 'Don\'t download roles listed as dependencies'
),
Option(
name: '--force-with-deps',
description: 'Force overwriting an existing role and its dependencies'
),
Option(
name: ['--requirements-file', '-r'],
description: 'A file containing a list of collections to be downloaded',
args: [
Arg(
name: 'requirements',
description: 'A file containing a list of collections to be downloaded',
template: ['filepaths']
)
]
),
Option(
name: ['--keep-scm-meta', '-g'],
description: 'Use tar instead of the scm archive option when packaging the role'
)
];