Implementation
final FigSpec azSpec = FigSpec(
name: 'az',
subcommands: [
FigSubcommand(
name: 'account',
description: 'Manage Azure subscription information',
loadSpec: 'az/2.53.0/account',
),
FigSubcommand(
name: 'acr',
description: 'Manage private registries with Azure Container Registries',
loadSpec: 'az/2.53.0/acr',
),
FigSubcommand(
name: 'ad',
description:
'Manage Azure Active Directory Graph entities needed for Role Based Access Control',
loadSpec: 'az/2.53.0/ad',
),
FigSubcommand(
name: 'adp',
description: 'Manage Azure Autonomous Development Platform resources',
loadSpec: 'az/2.53.0/adp',
),
FigSubcommand(
name: 'advisor',
description: 'Manage Azure Advisor',
loadSpec: 'az/2.53.0/advisor',
),
FigSubcommand(
name: 'afd',
description:
'Manage Azure Front Door Standard/Premium. For classical Azure Front Door, please refer https://docs.microsoft.com/en-us/cli/azure/network/front-door?view=azure-cli-latest',
loadSpec: 'az/2.53.0/afd',
),
FigSubcommand(
name: 'ai-examples',
description: 'Add AI powered examples to help content',
loadSpec: 'az/2.53.0/ai-examples',
),
FigSubcommand(
name: 'aks',
description: 'Manage Azure Kubernetes Services',
loadSpec: 'az/2.53.0/aks',
),
FigSubcommand(
name: 'alerts-management',
description: 'Manage Azure Alerts Management Service Resource',
loadSpec: 'az/2.53.0/alerts-management',
),
FigSubcommand(
name: 'alias',
description: 'Manage Azure CLI Aliases',
loadSpec: 'az/2.53.0/alias',
),
FigSubcommand(
name: 'amlfs',
description: 'Manage lustre file system',
loadSpec: 'az/2.53.0/amlfs',
),
FigSubcommand(
name: 'ams',
description: 'Manage Azure Media Services resources',
loadSpec: 'az/2.53.0/ams',
),
FigSubcommand(
name: 'apim',
description: 'Manage Azure API Management services',
loadSpec: 'az/2.53.0/apim',
),
FigSubcommand(
name: 'appconfig',
description: 'Manage App Configurations',
loadSpec: 'az/2.53.0/appconfig',
),
FigSubcommand(
name: 'appservice',
description: 'Manage App Service plans',
loadSpec: 'az/2.53.0/appservice',
),
FigSubcommand(
name: 'arcappliance',
description: 'Commands to manage Arc resource bridge',
loadSpec: 'az/2.53.0/arcappliance',
),
FigSubcommand(
name: 'arcdata',
description: 'Commands for using Azure Arc-enabled data services',
loadSpec: 'az/2.53.0/arcdata',
),
FigSubcommand(
name: 'aro',
description: 'Manage Azure Red Hat OpenShift clusters',
loadSpec: 'az/2.53.0/aro',
),
FigSubcommand(
name: 'artifacts',
description: 'Manage Azure Artifacts',
loadSpec: 'az/2.53.0/artifacts',
),
FigSubcommand(
name: 'attestation',
description: 'Manage Microsoft Azure Attestation (MAA)',
loadSpec: 'az/2.53.0/attestation',
),
FigSubcommand(
name: 'automanage',
description: 'Manage Automanage',
loadSpec: 'az/2.53.0/automanage',
),
FigSubcommand(
name: 'automation',
description: 'Manage Automation Account',
loadSpec: 'az/2.53.0/automation',
),
FigSubcommand(
name: 'azurestackhci',
description: 'Manage azurestackhci',
loadSpec: 'az/2.53.0/azurestackhci',
),
FigSubcommand(
name: 'backup',
description: 'Manage Azure Backups',
loadSpec: 'az/2.53.0/backup',
),
FigSubcommand(
name: 'baremetalinstance',
description: '(PREVIEW) Manage BareMetal Instances',
loadSpec: 'az/2.53.0/baremetalinstance',
),
FigSubcommand(
name: 'batch',
description: 'Manage Azure Batch',
loadSpec: 'az/2.53.0/batch',
),
FigSubcommand(
name: 'batchai',
description: 'Manage Batch AI resources',
loadSpec: 'az/2.53.0/batchai',
),
FigSubcommand(
name: 'bicep',
description: 'Bicep CLI command group',
loadSpec: 'az/2.53.0/bicep',
),
FigSubcommand(
name: 'billing',
description: 'Manage Azure Billing',
loadSpec: 'az/2.53.0/billing',
),
FigSubcommand(
name: 'billing-benefits',
description: 'Azure billing benefits commands',
loadSpec: 'az/2.53.0/billing-benefits',
),
FigSubcommand(
name: 'blockchain',
description: 'Manage blockchain',
loadSpec: 'az/2.53.0/blockchain',
),
FigSubcommand(
name: 'blueprint',
description: 'Commands to manage blueprint',
loadSpec: 'az/2.53.0/blueprint',
),
FigSubcommand(
name: 'boards',
description: 'Manage Azure Boards',
loadSpec: 'az/2.53.0/boards',
),
FigSubcommand(
name: 'bot',
description: 'Manage Microsoft Azure Bot Service',
loadSpec: 'az/2.53.0/bot',
),
FigSubcommand(
name: 'cache',
description:
'Commands to manage CLI objects cached using the --defer argument',
loadSpec: 'az/2.53.0/cache',
),
FigSubcommand(
name: 'capacity',
description: 'Manage capacity',
loadSpec: 'az/2.53.0/capacity',
),
FigSubcommand(
name: 'cdn',
description: 'Manage Azure Content Delivery Networks (CDNs)',
loadSpec: 'az/2.53.0/cdn',
),
FigSubcommand(
name: 'change-analysis',
description: 'List changes for resources',
loadSpec: 'az/2.53.0/change-analysis',
),
FigSubcommand(
name: 'cli-translator',
description: 'Translate ARM template or REST API to CLI scripts',
loadSpec: 'az/2.53.0/cli-translator',
),
FigSubcommand(
name: 'cloud',
description: 'Manage registered Azure clouds',
loadSpec: 'az/2.53.0/cloud',
),
FigSubcommand(
name: 'cloud-service',
description: 'Manage cloud service (extended support)',
loadSpec: 'az/2.53.0/cloud-service',
),
FigSubcommand(
name: 'cognitiveservices',
description: 'Manage Azure Cognitive Services accounts',
loadSpec: 'az/2.53.0/cognitiveservices',
),
FigSubcommand(
name: 'command-change',
description: 'Commands for CLI modules metadata management',
loadSpec: 'az/2.53.0/command-change',
),
FigSubcommand(
name: 'communication',
description: 'Manage communication service with communication',
loadSpec: 'az/2.53.0/communication',
),
FigSubcommand(
name: 'confcom',
description:
'Commands to generate security policies for confidential containers in Azure',
loadSpec: 'az/2.53.0/confcom',
),
FigSubcommand(
name: 'confidentialledger',
description: 'Manage Confidential Ledger',
loadSpec: 'az/2.53.0/confidentialledger',
),
FigSubcommand(
name: 'config',
description: 'Manage Azure CLI configuration',
loadSpec: 'az/2.53.0/config',
),
FigSubcommand(
name: 'configure',
description:
'Manage Azure CLI configuration. This command is interactive',
loadSpec: 'az/2.53.0/configure',
),
FigSubcommand(
name: 'confluent',
description: 'Manage confluent resources',
loadSpec: 'az/2.53.0/confluent',
),
FigSubcommand(
name: 'connectedk8s',
description: 'Commands to manage connected kubernetes clusters',
loadSpec: 'az/2.53.0/connectedk8s',
),
FigSubcommand(
name: 'connectedmachine',
description: 'Manage an Azure Arc-Enabled Server',
loadSpec: 'az/2.53.0/connectedmachine',
),
FigSubcommand(
name: 'connectedvmware',
description: 'Commands to manage Connected VMware',
loadSpec: 'az/2.53.0/connectedvmware',
),
FigSubcommand(
name: 'connection',
description:
'Commands to manage Service Connector local connections which allow local environment to connect Azure Resource. If you want to manage connection for compute service, please run \'az webapp/containerapp/spring connection\'',
loadSpec: 'az/2.53.0/connection',
),
FigSubcommand(
name: 'consumption',
description: 'Manage consumption of Azure resources',
loadSpec: 'az/2.53.0/consumption',
),
FigSubcommand(
name: 'container',
description: 'Manage Azure Container Instances',
loadSpec: 'az/2.53.0/container',
),
FigSubcommand(
name: 'containerapp',
description: 'Manage Azure Container Apps',
loadSpec: 'az/2.53.0/containerapp',
),
FigSubcommand(
name: 'cosmosdb',
description: 'Manage Azure Cosmos DB database accounts',
loadSpec: 'az/2.53.0/cosmosdb',
),
FigSubcommand(
name: 'costmanagement',
description: 'Manage cost and billing in Azure',
loadSpec: 'az/2.53.0/costmanagement',
),
FigSubcommand(
name: 'csvmware',
description: 'Manage Azure VMware Solution by CloudSimple',
loadSpec: 'az/2.53.0/csvmware',
),
FigSubcommand(
name: 'custom-providers',
description: 'Commands to manage custom providers',
loadSpec: 'az/2.53.0/custom-providers',
),
FigSubcommand(
name: 'customlocation',
description: 'Commands to Create, Get, List and Delete CustomLocations',
loadSpec: 'az/2.53.0/customlocation',
),
FigSubcommand(
name: 'databox',
description: 'Manage data box',
loadSpec: 'az/2.53.0/databox',
),
FigSubcommand(
name: 'databoxedge',
description: 'Support data box edge device and management',
loadSpec: 'az/2.53.0/databoxedge',
),
FigSubcommand(
name: 'databricks',
description: 'Manage databricks workspaces',
loadSpec: 'az/2.53.0/databricks',
),
FigSubcommand(
name: 'datadog',
description: 'Manage datadog',
loadSpec: 'az/2.53.0/datadog',
),
FigSubcommand(
name: 'datafactory',
description: 'Manage Data Factory',
loadSpec: 'az/2.53.0/datafactory',
),
FigSubcommand(
name: 'datamigration',
description: 'Manage Data Migration',
loadSpec: 'az/2.53.0/datamigration',
),
FigSubcommand(
name: 'dataprotection',
description: 'Manage dataprotection',
loadSpec: 'az/2.53.0/dataprotection',
),
FigSubcommand(
name: 'datashare',
description: 'Manage Data Share',
loadSpec: 'az/2.53.0/datashare',
),
FigSubcommand(
name: 'dedicated-hsm',
description: 'Manage dedicated hsm with hardware security modules',
loadSpec: 'az/2.53.0/dedicated-hsm',
),
FigSubcommand(
name: 'demo',
description:
'Demos for designing, developing and demonstrating Azure CLI',
loadSpec: 'az/2.53.0/demo',
),
FigSubcommand(
name: 'deployment',
description:
'Manage Azure Resource Manager template deployment at subscription scope',
loadSpec: 'az/2.53.0/deployment',
),
FigSubcommand(
name: 'deployment-scripts',
description:
'Manage deployment scripts at subscription or resource group scope',
loadSpec: 'az/2.53.0/deployment-scripts',
),
FigSubcommand(
name: 'desktopvirtualization',
description: 'Manage desktop virtualization',
loadSpec: 'az/2.53.0/desktopvirtualization',
),
FigSubcommand(
name: 'devcenter',
description: 'Manage resources with devcenter',
loadSpec: 'az/2.53.0/devcenter',
),
FigSubcommand(
name: 'devops',
description: 'Manage Azure DevOps organization level operations',
loadSpec: 'az/2.53.0/devops',
),
FigSubcommand(
name: 'disk',
description: 'Manage Azure Managed Disks',
loadSpec: 'az/2.53.0/disk',
),
FigSubcommand(
name: 'disk-access',
description: 'Manage disk access resources',
loadSpec: 'az/2.53.0/disk-access',
),
FigSubcommand(
name: 'disk-encryption-set',
description: 'Disk Encryption Set resource',
loadSpec: 'az/2.53.0/disk-encryption-set',
),
FigSubcommand(
name: 'disk-pool',
description: 'Manage Azure disk pool',
loadSpec: 'az/2.53.0/disk-pool',
),
FigSubcommand(
name: 'dla',
description: 'Manage Data Lake Analytics accounts, jobs, and catalogs',
loadSpec: 'az/2.53.0/dla',
),
FigSubcommand(
name: 'dls',
description: 'Manage Data Lake Store accounts and filesystems',
loadSpec: 'az/2.53.0/dls',
),
FigSubcommand(
name: 'dms',
description: 'Manage Azure Data Migration Service (classic) instances',
loadSpec: 'az/2.53.0/dms',
),
FigSubcommand(
name: 'dnc',
description: 'Manage Delegated Network',
loadSpec: 'az/2.53.0/dnc',
),
FigSubcommand(
name: 'dns-resolver',
description: 'Manage Dns Resolver',
loadSpec: 'az/2.53.0/dns-resolver',
),
FigSubcommand(
name: 'dt',
description: 'Manage Azure Digital Twins solutions & infrastructure',
loadSpec: 'az/2.53.0/dt',
),
FigSubcommand(
name: 'dynatrace',
description: 'Manage dynatrace',
loadSpec: 'az/2.53.0/dynatrace',
),
FigSubcommand(
name: 'edgeorder',
description: 'Manage Edge Order',
loadSpec: 'az/2.53.0/edgeorder',
),
FigSubcommand(
name: 'elastic',
description: 'Manage Microsoft Elastic',
loadSpec: 'az/2.53.0/elastic',
),
FigSubcommand(
name: 'elastic-san',
description: 'Manage Elastic SAN',
loadSpec: 'az/2.53.0/elastic-san',
),
FigSubcommand(
name: 'eventgrid',
description:
'Manage Azure Event Grid topics, domains, domain topics, system topics partner topics, event subscriptions, system topic event subscriptions and partner topic event subscriptions',
loadSpec: 'az/2.53.0/eventgrid',
),
FigSubcommand(
name: 'eventhubs',
description: 'Eventhubs',
loadSpec: 'az/2.53.0/eventhubs',
),
FigSubcommand(
name: 'extension',
description: 'Manage and update CLI extensions',
loadSpec: 'az/2.53.0/extension',
),
FigSubcommand(
name: 'feature',
description: 'Manage resource provider features',
loadSpec: 'az/2.53.0/feature',
),
FigSubcommand(
name: 'feedback',
description: 'Send feedback to the Azure CLI Team',
loadSpec: 'az/2.53.0/feedback',
),
FigSubcommand(
name: 'find',
description:
'I\'m an AI robot, my advice is based on our Azure documentation as well as the usage patterns of Azure CLI and Azure ARM users. Using me improves Azure products and documentation',
loadSpec: 'az/2.53.0/find',
),
FigSubcommand(
name: 'fleet',
description: 'Commands to manage fleet',
loadSpec: 'az/2.53.0/fleet',
),
FigSubcommand(
name: 'fluid-relay',
description: 'Manage Fluid Relay',
loadSpec: 'az/2.53.0/fluid-relay',
),
FigSubcommand(
name: 'footprint',
description: '',
loadSpec: 'az/2.53.0/footprint',
),
FigSubcommand(
name: 'functionapp',
description:
'Manage function apps. To install the Azure Functions Core tools see https://github.com/Azure/azure-functions-core-tools',
loadSpec: 'az/2.53.0/functionapp',
),
FigSubcommand(
name: 'fzf',
description: 'Commands to select active or default objects via fzf',
loadSpec: 'az/2.53.0/fzf',
),
FigSubcommand(
name: 'grafana',
description: 'Commands to manage Azure Grafana instanced',
loadSpec: 'az/2.53.0/grafana',
),
FigSubcommand(
name: 'graph',
description: 'Query the resources managed by Azure Resource Manager',
loadSpec: 'az/2.53.0/graph',
),
FigSubcommand(
name: 'graph-services',
description: 'Make operations on Microsoft.GraphServices resource types',
loadSpec: 'az/2.53.0/graph-services',
),
FigSubcommand(
name: 'group',
description: 'Manage resource groups and template deployments',
loadSpec: 'az/2.53.0/group',
),
FigSubcommand(
name: 'guestconfig',
description: 'Manage Guest Configuration',
loadSpec: 'az/2.53.0/guestconfig',
),
FigSubcommand(
name: 'hack',
description:
'Commands to manage resources commonly used for student hacks',
loadSpec: 'az/2.53.0/hack',
),
FigSubcommand(
name: 'hanainstance',
description: '(PREVIEW) Manage Azure SAP HANA Instance',
loadSpec: 'az/2.53.0/hanainstance',
),
FigSubcommand(
name: 'hdinsight',
description: 'Manage HDInsight resources',
loadSpec: 'az/2.53.0/hdinsight',
),
FigSubcommand(
name: 'healthbot',
description: 'Manage bot with healthbot',
loadSpec: 'az/2.53.0/healthbot',
),
FigSubcommand(
name: 'healthcareapis',
description: 'Manage Healthcare Apis',
loadSpec: 'az/2.53.0/healthcareapis',
),
FigSubcommand(
name: 'hpc-cache',
description: 'Commands to manage hpc cache',
loadSpec: 'az/2.53.0/hpc-cache',
),
FigSubcommand(
name: 'hybridaks',
description: 'Manage hybridaks provisioned clusters',
loadSpec: 'az/2.53.0/hybridaks',
),
FigSubcommand(
name: 'identity',
description: 'Managed Identities',
loadSpec: 'az/2.53.0/identity',
),
FigSubcommand(
name: 'image',
description: 'Manage custom virtual machine images',
loadSpec: 'az/2.53.0/image',
),
FigSubcommand(
name: 'import-export',
description: 'Manage Import Export',
loadSpec: 'az/2.53.0/import-export',
),
FigSubcommand(
name: 'init',
description: 'It\'s an effortless setting up tool for configs',
loadSpec: 'az/2.53.0/init',
),
FigSubcommand(
name: 'interactive',
description:
'Start interactive mode. Installs the Interactive extension if not installed already',
loadSpec: 'az/2.53.0/interactive',
),
FigSubcommand(
name: 'internet-analyzer',
description: 'Commands to manage internet analyzer',
loadSpec: 'az/2.53.0/internet-analyzer',
),
FigSubcommand(
name: 'iot',
description: 'Manage Internet of Things (IoT) assets',
loadSpec: 'az/2.53.0/iot',
),
FigSubcommand(
name: 'k8s-configuration',
description:
'Commands to manage resources from Microsoft.KubernetesConfiguration',
loadSpec: 'az/2.53.0/k8s-configuration',
),
FigSubcommand(
name: 'k8s-extension',
description: 'Commands to manage Kubernetes Extensions',
loadSpec: 'az/2.53.0/k8s-extension',
),
FigSubcommand(
name: 'k8sconfiguration',
description: 'Commands to manage Kubernetes configuration',
loadSpec: 'az/2.53.0/k8sconfiguration',
),
FigSubcommand(
name: 'keyvault',
description: 'Manage KeyVault keys, secrets, and certificates',
loadSpec: 'az/2.53.0/keyvault',
),
FigSubcommand(
name: 'kusto',
description: 'Manage Azure Kusto resources',
loadSpec: 'az/2.53.0/kusto',
),
FigSubcommand(
name: 'lab',
description: 'Manage Azure DevTest Labs',
loadSpec: 'az/2.53.0/lab',
),
FigSubcommand(
name: 'load',
description: 'Manage Azure Load Testing resources',
loadSpec: 'az/2.53.0/load',
),
FigSubcommand(
name: 'lock',
description: 'Manage Azure locks',
loadSpec: 'az/2.53.0/lock',
),
FigSubcommand(
name: 'logic',
description: 'Manage logic',
loadSpec: 'az/2.53.0/logic',
),
FigSubcommand(
name: 'logicapp',
description: 'Manage logic apps',
loadSpec: 'az/2.53.0/logicapp',
),
FigSubcommand(
name: 'login',
description: 'Log in to Azure',
loadSpec: 'az/2.53.0/login',
),
FigSubcommand(
name: 'logout',
description: 'Log out to remove access to Azure subscriptions',
loadSpec: 'az/2.53.0/logout',
),
FigSubcommand(
name: 'logz',
description: 'Manage Microsoft Logz',
loadSpec: 'az/2.53.0/logz',
),
FigSubcommand(
name: 'maintenance',
description: 'Manage Maintenance',
loadSpec: 'az/2.53.0/maintenance',
),
FigSubcommand(
name: 'managed-cassandra',
description: 'Azure Managed Cassandra',
loadSpec: 'az/2.53.0/managed-cassandra',
),
FigSubcommand(
name: 'managedapp',
description:
'Manage template solutions provided and maintained by Independent Software Vendors (ISVs)',
loadSpec: 'az/2.53.0/managedapp',
),
FigSubcommand(
name: 'managedservices',
description:
'Manage the registration assignments and definitions in Azure',
loadSpec: 'az/2.53.0/managedservices',
),
FigSubcommand(
name: 'managementpartner',
description:
'Allows the partners to associate a Microsoft Partner Network(MPN) ID to a user or service principal in the customer\'s Azure directory',
loadSpec: 'az/2.53.0/managementpartner',
),
FigSubcommand(
name: 'maps',
description: 'Manage Azure Maps',
loadSpec: 'az/2.53.0/maps',
),
FigSubcommand(
name: 'mariadb',
description: 'Manage Azure Database for MariaDB servers',
loadSpec: 'az/2.53.0/mariadb',
),
FigSubcommand(
name: 'mesh',
description: '(PREVIEW) Manage Azure Service Fabric Mesh Resources',
loadSpec: 'az/2.53.0/mesh',
),
FigSubcommand(
name: 'ml',
description:
'Manage Azure Machine Learning resources with the Azure CLI ML extension v1',
loadSpec: 'az/2.53.0/ml',
),
FigSubcommand(
name: 'mobile-network',
description: 'Manage mobile network',
loadSpec: 'az/2.53.0/mobile-network',
),
FigSubcommand(
name: 'monitor',
description: 'Manage the Azure Monitor Service',
loadSpec: 'az/2.53.0/monitor',
),
FigSubcommand(
name: 'mysql',
description: 'Manage Azure Database for MySQL servers',
loadSpec: 'az/2.53.0/mysql',
),
FigSubcommand(
name: 'netappfiles',
description: 'Manage Azure NetApp Files (ANF) Resources',
loadSpec: 'az/2.53.0/netappfiles',
),
FigSubcommand(
name: 'network',
description: 'Manage Azure Network resources',
loadSpec: 'az/2.53.0/network',
),
FigSubcommand(
name: 'network-function',
description: 'Manage network function',
loadSpec: 'az/2.53.0/network-function',
),
FigSubcommand(
name: 'networkcloud',
description: 'Manage Network Cloud resources',
loadSpec: 'az/2.53.0/networkcloud',
),
FigSubcommand(
name: 'networkfabric',
description: 'Manage Azure Network Fabric Management Service API',
loadSpec: 'az/2.53.0/networkfabric',
),
FigSubcommand(
name: 'new-relic',
description: 'Manage Azure NewRelic resources',
loadSpec: 'az/2.53.0/new-relic',
),
FigSubcommand(
name: 'next',
description: 'Recommend the possible next set of commands to take',
loadSpec: 'az/2.53.0/next',
),
FigSubcommand(
name: 'nginx',
description: 'Manage NGINX deployment resources',
loadSpec: 'az/2.53.0/nginx',
),
FigSubcommand(
name: 'notification-hub',
description: 'Manage notification hubs',
loadSpec: 'az/2.53.0/notification-hub',
),
FigSubcommand(
name: 'offazure',
description: 'Manage on-premise resources for migrate',
loadSpec: 'az/2.53.0/offazure',
),
FigSubcommand(
name: 'orbital',
description: 'Azure Orbital Ground Station as-a-Service (GSaaS)',
loadSpec: 'az/2.53.0/orbital',
),
FigSubcommand(
name: 'palo-alto',
description: 'Manage palo-alto networks resource',
loadSpec: 'az/2.53.0/palo-alto',
),
FigSubcommand(
name: 'partnercenter',
description: 'Partner Center management',
loadSpec: 'az/2.53.0/partnercenter',
),
FigSubcommand(
name: 'peering',
description: 'Manage peering',
loadSpec: 'az/2.53.0/peering',
),
FigSubcommand(
name: 'pipelines',
description: 'Manage Azure Pipelines',
loadSpec: 'az/2.53.0/pipelines',
),
FigSubcommand(
name: 'policy',
description: 'Manage resource policies',
loadSpec: 'az/2.53.0/policy',
),
FigSubcommand(
name: 'portal',
description: 'Manage Portal',
loadSpec: 'az/2.53.0/portal',
),
FigSubcommand(
name: 'postgres',
description: 'Manage Azure Database for PostgreSQL servers',
loadSpec: 'az/2.53.0/postgres',
),
FigSubcommand(
name: 'powerbi',
description: 'Manage PowerBI resources',
loadSpec: 'az/2.53.0/powerbi',
),
FigSubcommand(
name: 'ppg',
description: 'Manage Proximity Placement Groups',
loadSpec: 'az/2.53.0/ppg',
),
FigSubcommand(
name: 'private-link',
description: 'Private-link association CLI command group',
loadSpec: 'az/2.53.0/private-link',
),
FigSubcommand(
name: 'provider',
description: 'Manage resource providers',
loadSpec: 'az/2.53.0/provider',
),
FigSubcommand(
name: 'providerhub',
description: 'Manage resources with ProviderHub',
loadSpec: 'az/2.53.0/providerhub',
),
FigSubcommand(
name: 'purview',
description: 'Manage Purview',
loadSpec: 'az/2.53.0/purview',
),
FigSubcommand(
name: 'quantum',
description:
'Manage Azure Quantum Workspaces and submit jobs to Azure Quantum Providers',
loadSpec: 'az/2.53.0/quantum',
),
FigSubcommand(
name: 'qumulo',
description: 'Manage qumulo',
loadSpec: 'az/2.53.0/qumulo',
),
FigSubcommand(
name: 'quota',
description: 'Manage Azure Quota Extension API',
loadSpec: 'az/2.53.0/quota',
),
FigSubcommand(
name: 'redis',
description: 'Manage dedicated Redis caches for your Azure applications',
loadSpec: 'az/2.53.0/redis',
),
FigSubcommand(
name: 'redisenterprise',
description: 'Manage the redisenterprise cache',
loadSpec: 'az/2.53.0/redisenterprise',
),
FigSubcommand(
name: 'relay',
description:
'Manage Azure Relay Service namespaces, WCF relays, hybrid connections, and rules',
loadSpec: 'az/2.53.0/relay',
),
FigSubcommand(
name: 'remote-rendering-account',
description: 'Manage remote rendering account with mixed reality',
loadSpec: 'az/2.53.0/remote-rendering-account',
),
FigSubcommand(
name: 'repos',
description: 'Manage Azure Repos',
loadSpec: 'az/2.53.0/repos',
),
FigSubcommand(
name: 'reservations',
description: 'Azure Reservations',
loadSpec: 'az/2.53.0/reservations',
),
FigSubcommand(
name: 'resource',
description: 'Manage Azure resources',
loadSpec: 'az/2.53.0/resource',
),
FigSubcommand(
name: 'resource-mover',
description: 'Manage Resource Mover Service API',
loadSpec: 'az/2.53.0/resource-mover',
),
FigSubcommand(
name: 'resourcemanagement',
description: 'Resourcemanagement CLI command group',
loadSpec: 'az/2.53.0/resourcemanagement',
),
FigSubcommand(
name: 'rest',
description: 'Invoke a custom request',
loadSpec: 'az/2.53.0/rest',
),
FigSubcommand(
name: 'restore-point',
description: 'Manage restore point with res',
loadSpec: 'az/2.53.0/restore-point',
),
FigSubcommand(
name: 'role',
description:
'Manage user roles for access control with Azure Active Directory and service principals',
loadSpec: 'az/2.53.0/role',
),
FigSubcommand(
name: 'sapmonitor',
description: '(PREVIEW) Manage Azure SAP Monitor',
loadSpec: 'az/2.53.0/sapmonitor',
),
FigSubcommand(
name: 'scenario',
description: 'E2E Scenario Usage Guidance',
loadSpec: 'az/2.53.0/scenario',
),
FigSubcommand(
name: 'scvmm',
description: 'Commands for managing Arc for SCVMM resources',
loadSpec: 'az/2.53.0/scvmm',
),
FigSubcommand(
name: 'search',
description: 'Manage Azure Search services, admin keys and query keys',
loadSpec: 'az/2.53.0/search',
),
FigSubcommand(
name: 'security',
description:
'Manage your security posture with Microsoft Defender for Cloud',
loadSpec: 'az/2.53.0/security',
),
FigSubcommand(
name: 'self-help',
description:
'Azure SelfHelp will help you troubleshoot issues with Azure resources',
loadSpec: 'az/2.53.0/self-help',
),
FigSubcommand(
name: 'self-test',
description: 'Runs a self-test of the CLI',
loadSpec: 'az/2.53.0/self-test',
),
FigSubcommand(
name: 'sentinel',
description: 'Manage Microsoft Sentinel',
loadSpec: 'az/2.53.0/sentinel',
),
FigSubcommand(
name: 'serial-console',
description:
'Connect to the Serial Console of a Linux/Windows Virtual Machine or VMSS Instance',
loadSpec: 'az/2.53.0/serial-console',
),
FigSubcommand(
name: 'servicebus',
description: 'Servicebus',
loadSpec: 'az/2.53.0/servicebus',
),
FigSubcommand(
name: 'sf',
description: 'Manage and administer Azure Service Fabric clusters',
loadSpec: 'az/2.53.0/sf',
),
FigSubcommand(
name: 'sig',
description: 'Manage shared image gallery',
loadSpec: 'az/2.53.0/sig',
),
FigSubcommand(
name: 'signalr',
description: 'Manage Azure SignalR Service',
loadSpec: 'az/2.53.0/signalr',
),
FigSubcommand(
name: 'site-recovery',
description: 'Manage Site Recovery Service',
loadSpec: 'az/2.53.0/site-recovery',
),
FigSubcommand(
name: 'snapshot',
description:
'Manage point-in-time copies of managed disks, native blobs, or other snapshots',
loadSpec: 'az/2.53.0/snapshot',
),
FigSubcommand(
name: 'spatial-anchors-account',
description: 'Manage spatial anchor account with mixed reality',
loadSpec: 'az/2.53.0/spatial-anchors-account',
),
FigSubcommand(
name: 'sphere',
description: 'Manage Azure Sphere',
loadSpec: 'az/2.53.0/sphere',
),
FigSubcommand(
name: 'spring',
description: 'Commands to manage Azure Spring Apps',
loadSpec: 'az/2.53.0/spring',
),
FigSubcommand(
name: 'spring-cloud',
description: 'Commands to manage Azure Spring Cloud',
loadSpec: 'az/2.53.0/spring-cloud',
),
FigSubcommand(
name: 'sql',
description: 'Manage Azure SQL Databases and Data Warehouses',
loadSpec: 'az/2.53.0/sql',
),
FigSubcommand(
name: 'ssh',
description:
'SSH into resources (Azure VMs, Arc servers, etc) using AAD issued openssh certificates',
loadSpec: 'az/2.53.0/ssh',
),
FigSubcommand(
name: 'sshkey',
description: 'Manage ssh public key with vm',
loadSpec: 'az/2.53.0/sshkey',
),
FigSubcommand(
name: 'stack',
description:
'A deployment stack is a native Azure resource type that enables you to perform operations on a resource collection as an atomic unit',
loadSpec: 'az/2.53.0/stack',
),
FigSubcommand(
name: 'stack-hci',
description: 'Manage Azure Stack HCI',
loadSpec: 'az/2.53.0/stack-hci',
),
FigSubcommand(
name: 'staticwebapp',
description: 'Manage static apps',
loadSpec: 'az/2.53.0/staticwebapp',
),
FigSubcommand(
name: 'storage',
description: 'Manage Azure Cloud Storage resources',
loadSpec: 'az/2.53.0/storage',
),
FigSubcommand(
name: 'storage-mover',
description: 'Manage top-level Storage Mover resource',
loadSpec: 'az/2.53.0/storage-mover',
),
FigSubcommand(
name: 'storagesync',
description: 'Manage Azure File Sync',
loadSpec: 'az/2.53.0/storagesync',
),
FigSubcommand(
name: 'stream-analytics',
description: 'Manage Stream Analytics',
loadSpec: 'az/2.53.0/stream-analytics',
),
FigSubcommand(
name: 'support',
description: 'Manage Azure support resource',
loadSpec: 'az/2.53.0/support',
),
FigSubcommand(
name: 'survey',
description: 'Take Azure CLI survey',
loadSpec: 'az/2.53.0/survey',
),
FigSubcommand(
name: 'synapse',
description: 'Manage and operate Synapse Workspace, Spark Pool, SQL Pool',
loadSpec: 'az/2.53.0/synapse',
),
FigSubcommand(
name: 'tag',
description: 'Tag Management on a resource',
loadSpec: 'az/2.53.0/tag',
),
FigSubcommand(
name: 'term',
description: 'Manage marketplace agreement with marketplaceordering',
loadSpec: 'az/2.53.0/term',
),
FigSubcommand(
name: 'ts',
description:
'Manage template specs at subscription or resource group scope',
loadSpec: 'az/2.53.0/ts',
),
FigSubcommand(
name: 'tsi',
description: 'Manage Azure Time Series Insights',
loadSpec: 'az/2.53.0/tsi',
),
FigSubcommand(
name: 'upgrade',
description: 'Upgrade Azure CLI and extensions',
loadSpec: 'az/2.53.0/upgrade',
),
FigSubcommand(
name: 'version',
description:
'Show the versions of Azure CLI modules and extensions in JSON format by default or format configured by --output',
loadSpec: 'az/2.53.0/version',
),
FigSubcommand(
name: 'vm',
description: 'Manage Linux or Windows virtual machines',
loadSpec: 'az/2.53.0/vm',
),
FigSubcommand(
name: 'vmss',
description:
'Manage groupings of virtual machines in an Azure Virtual Machine Scale Set (VMSS)',
loadSpec: 'az/2.53.0/vmss',
),
FigSubcommand(
name: 'vmware',
description: 'Commands to manage Azure VMware Solution',
loadSpec: 'az/2.53.0/vmware',
),
FigSubcommand(
name: 'webapp',
description: 'Manage web apps',
loadSpec: 'az/2.53.0/webapp',
),
FigSubcommand(
name: 'webpubsub',
description: 'Commands to manage Webpubsub',
loadSpec: 'az/2.53.0/webpubsub',
),
FigSubcommand(
name: 'workloads',
description: 'Manage workloads',
loadSpec: 'az/2.53.0/workloads',
),
],
options: [
FigOption(
name: ['--debug'],
description: 'Increase logging verbosity to show all debug logs',
isPersistent: true,
),
FigOption(
name: ['--help', '-h'],
description: 'Show this help message and exit',
isPersistent: true,
),
FigOption(
name: ['--only-show-errors'],
description: 'Only show errors, suppressing warnings',
isPersistent: true,
),
FigOption(
name: ['--output', '-o'],
description: 'Output format',
isPersistent: true,
args: [
FigArg(
name: 'output',
suggestions: [
'json',
'jsonc',
'none',
'table',
'tsv',
'yaml',
'yamlc'
],
),
],
),
FigOption(
name: ['--query'],
description:
'JMESPath query string. See http://jmespath.org/ for more information and examples',
isPersistent: true,
args: [
FigArg(
name: 'query',
),
],
),
FigOption(
name: ['--subscription'],
description:
'Name or ID of subscription. You can configure the default subscription using az account set -s NAME_OR_ID',
isPersistent: true,
args: [
FigArg(
name: 'subscription',
),
],
),
FigOption(
name: ['--verbose'],
description:
'Increase logging verbosity. Use --debug for full debug logs',
isPersistent: true,
),
],
);