configPairs top-level property
Implementation
final Map<String, ConfigPair> configPairs = {
'build.jobs': ConfigPair(
description:
'Sets the maximum number of compiler processes to run in parallel'),
'build.rustc': ConfigPair(description: 'Path to the rustc compiler'),
'build.rustc-wrapper':
ConfigPair(description: 'Sets a wrapper to execute instead of rustc'),
'build.target': ConfigPair(
description: 'The default target platform triples to compile to'),
'build.target-dir': ConfigPair(
description: 'The path to where all compiler output is placed'),
'build.rustflags':
ConfigPair(description: 'Extra command-line flags to pass to rustc'),
'build.rustdocflags':
ConfigPair(description: 'Extra command-line flags to pass to rustdoc'),
'build.incremental': ConfigPair(
description: 'Whether or not to perform incremental compilation',
tomlSuggestions: tomlBool),
'build.dep-info-basedir': ConfigPair(
description: 'Strips the given path prefix from dep info file paths'),
'doc.browser': ConfigPair(
description:
'This option sets the browser to be used by cargo doc, overriding the BROWSER environment variable when opening documentation with the --open option'),
'cargo-new.vcs': ConfigPair(
description:
'Specifies the source control system to use for initializing a new repository',
tomlSuggestions: vcsOptions
.map((vcs) => FigSuggestion(
name: '"${vcs.nameSingle}"',
insertValue: '"${vcs.nameSingle}"',
icon: vcs.icon,
description: vcs.description,
))
.toList(),
),
'future-incompat-report.frequency': ConfigPair(
description:
'Controls how often we display a notification to the terminal when a future incompat report is available',
tomlSuggestions: [
FigSuggestion(
name: '"always"',
insertValue: '"always"',
description:
'Always display a notification when a command (e.g. cargo build) produces a future incompat report'),
FigSuggestion(
name: '"never"',
insertValue: '"never"',
description: 'Never display a notification'),
],
),
'http.debug': ConfigPair(
description: 'If true, enables debugging of HTTP requests',
tomlSuggestions: tomlBool),
'http.proxy': ConfigPair(description: 'Sets an HTTP and HTTPS proxy to use'),
'http.timeout': ConfigPair(
description: 'Sets the timeout for each HTTP request, in seconds'),
'http.cainfo':
ConfigPair(description: 'Sets the path to a CA certificate bundle'),
'http.check-revoke': ConfigPair(
description:
'This determines whether or not TLS certificate revocation checks should be performed. This only works on Windows',
tomlSuggestions: tomlBool),
'http.ssl-version':
ConfigPair(description: 'This sets the minimum TLS version to use'),
'http.low-speed-limit': ConfigPair(
description:
'This setting controls timeout behavior for slow connections'),
'http.multiplexing': ConfigPair(
description:
'When `true`, Cargo will attempt to use the HTTP2 protocol with multiplexing',
tomlSuggestions: tomlBool),
'http.user-agent':
ConfigPair(description: 'Specifies a custom user-agent header to use'),
'install.root': ConfigPair(
description:
'Sets the path to the root directory for installing executables for `cargo install`'),
'net.retry': ConfigPair(
description: 'Number of times to retry possibly spurious network errors'),
'net.git-fetch-with-cli': ConfigPair(
description:
'If this is `true`, then Cargo will use the git executable to fetch registry indexes and git dependencies. If `false`, then it uses a built-in git library',
tomlSuggestions: tomlBool),
'net.offline': ConfigPair(
description:
'If this is true, then Cargo will avoid accessing the network, and attempt to proceed with locally cached data',
tomlSuggestions: tomlBool),
};