DocNode class
Constructors
- DocNode({required String kind, required String name, String? declarationKind, NamespaceDef? namespaceDef, InterfaceDef? interfaceDef, ClassDef? classDef, dynamic variableDef, dynamic functionDef, dynamic enumDef, dynamic typeAliasDef, dynamic importDef})
-
DocNode.fromJson(Map<
String, dynamic> json) -
factory
Properties
- classDef → ClassDef?
-
final
- declarationKind → String?
-
final
- enumDef → dynamic
-
final
- functionDef → dynamic
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- importDef → dynamic
-
final
- interfaceDef → InterfaceDef?
-
final
- kind → String
-
final
- name → String
-
final
- namespaceDef → NamespaceDef?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- typeAliasDef → dynamic
-
final
- variableDef → dynamic
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited