configurableCommandOptions top-level property
Implementation
final List<Option> configurableCommandOptions = [
Option(
name: '--excludes',
description: 'List of file patterns or directories in quotes to exclude when formatting. This overrides what is specified in the config file',
args: [
Arg(
name: 'pattern',
template: ['filepaths', 'folders']
)
],
isRepeatable: true
),
Option(
name: '--allow-node-modules',
description: 'Allows traversing node module directories (unstable - This flag will be renamed to be non-node specific in the future)'
)
];