congratulate top-level property
Implementation
final List<FigOption> congratulate = [
FigOption(
name: ['--congratulate'],
description:
'Show output even when there are no errors, warnings, hints, or lints. Ignored if --watch is specified',
),
FigOption(
name: ['--no-congratulate'],
description:
'Hide output even when there are no errors, warnings, hints, or lints. Ignored if --watch is specified',
),
];