nullAssertions top-level property
Implementation
final List<FigOption> nullAssertions = [
FigOption(
name: ['--null-assertions'],
description:
'Perform additional null assertions on the boundaries of migrated and un-migrated code. This setting is not currently supported on desktop devices',
),
FigOption(
name: ['--no-null-assertions'],
description:
'Not performing additional null assertions on the boundaries of migrated and un-migrated code. This setting is not currently supported on desktop devices',
),
];