offline top-level property
Implementation
final List<FigOption> offline = [
FigOption(
name: ['--offline'],
description:
'When "flutter pub get" is run by the create command, this indicates whether to run it in offline mode or not. In offline mode, it will need to have all dependencies already available in the pub cache to succeed',
),
FigOption(
name: ['--no-offline'],
),
];