preamble top-level property
Implementation
final List<FigOption> preamble = [
FigOption(
name: ['--preamble'],
description:
'When analyzing the flutter repository, display the number of files that will be analyzed. Ignored if --watch is specified',
),
FigOption(
name: ['--no-preamble'],
description:
"When analyzing the flutter repository, don't display the number of files that will be analyzed. Ignored if --watch is specified",
),
];