target top-level property
Implementation
final FigOption target = FigOption(
name: ['-t', '--target'],
insertValue: '--target ',
description:
'The main entry-point file of the application, as run on the device. If the --target option is omitted, but a file name is provided on the command line, then that is used instead. (defaults to "lib/main.dart")',
args: [
FigArg(
name: '.dart file path',
template: 'filepaths',
),
],
);