trackWidgetCreation top-level property
Implementation
final List<FigOption> trackWidgetCreation = [
FigOption(
name: ['--track-widget-creation'],
description:
'Track widget creation locations. This enables features such as the widget inspector. This parameter is only functional in debug mode (i.e. when compiling JIT, not AOT)',
),
FigOption(
name: ['--no-track-widget-creation'],
description:
'No tracking widget creation locations. This disables features such as the widget inspector. This parameter is only functional in debug mode (i.e. when compiling JIT, not AOT)',
),
];