useTestFonts top-level property
Implementation
final List<FigOption> useTestFonts = [
FigOption(
name: ['--use-test-fonts'],
description:
'Enable (and default to) the "Ahem" font. This is a special font used in tests to remove any dependencies on the font metrics. It is enabled when you use "flutter test". Set this flag when running a test using "flutter run" for debugging purposes. This flag is only available when running in debug mode',
),
FigOption(
name: ['--no-use-test-fonts'],
),
];