globalOptions top-level property
Implementation
final globalOptions = [
...resolutionAndExecutionOptions,
Option(
name: ['-a'],
description: 'Force rebuilding of packages that are already up-to-date'),
Option(
name: ['-p'],
description: 'The number of programs, such as build commands or',
args: [Arg(name: 'programs')]),
Option(
name: ['-race'],
description:
'Enable data race detection.\nSupported only on linux/amd64, freebsd/amd64, darwin/amd64, windows/amd64,\nlinux/ppc64le and linux/arm64 (only for 48-bit VMA)'),
Option(
name: ['-msan'],
description:
'Enable interoperation with memory sanitizer.\nSupported only on linux/amd64, linux/arm64\nand only with Clang/LLVM as the host C compiler.\nOn linux/arm64, pie build mode will be used'),
Option(
name: ['-work'],
description:
'Print the name of the temporary work directory and\ndo not delete it when exiting'),
Option(
name: ['-asmflags'],
insertValue: '-asmflags=\'{cursor}\'',
description: 'Arguments to pass on each go tool asm invocation',
args: [Arg(name: 'flag', isVariadic: true)]),
Option(
name: ['-buildmode'],
description: 'Build mode to use. See \'go help buildmode\' for more',
args: [Arg(name: 'mode', suggestions: buildModeSuggestions)]),
Option(
name: ['-compiler'],
description:
'Name of compiler to use, as in runtime.Compiler (gccgo or gc)',
args: [Arg(name: 'name')]),
Option(
name: ['-gccgoflags'],
insertValue: '--gccgoflags=\'{cursor}\'',
description: 'Arguments to pass on each gccgo compiler/linker invocation',
args: [Arg(name: 'flag', isVariadic: true)]),
Option(
name: ['-gcflags'],
insertValue: '-gcflags=\'{cursor}\'',
description: 'Arguments to pass on each go tool compile invocation',
args: [Arg(name: 'flag', isVariadic: true)]),
Option(
name: ['-installsuffix'],
description:
'A suffix to use in the name of the package installation directory,',
args: [Arg(name: 'suffix')]),
Option(
name: ['-ldflags'],
insertValue: '-ldflags=\'{cursor}\'',
description: 'Arguments to pass on each go tool link invocation',
args: [Arg(name: 'flag', isVariadic: true)]),
Option(
name: ['-linkshared'],
description:
'Build code that will be linked against shared libraries previously'),
Option(
name: ['-mod'],
description: 'Module download mode to use: readonly, vendor, or mod',
args: [
Arg(name: 'mode', suggestions: [
FigSuggestion(name: 'readonly'),
FigSuggestion(name: 'vendor'),
FigSuggestion(name: 'mod')
])
]),
Option(
name: ['-modcacherw'],
description:
'Leave newly-created directories in the module cache read-write'),
Option(
name: ['-modfile'],
description:
'In module aware mode, read (and possibly write) an alternate go.mod file instead of the one in the module root directory',
args: [Arg(name: 'file')]),
Option(
name: ['-overlay'],
description:
'Read a JSON config file that provides an overlay for build operations',
args: [Arg(name: 'file')]),
Option(
name: ['-pkgdir'],
description:
'Install and load all packages from dir instead of the usual locations',
args: [Arg(name: 'dir')]),
Option(name: [
'-trimpath'
], description: 'Remove all file system paths from the resulting executable'),
];