warningModeArg top-level property
Implementation
final FigArg warningModeArg = FigArg(
name: 'mode',
defaultValue: 'summary',
suggestions: [
FigSuggestion(
name: 'all',
description: 'Log all warnings',
),
FigSuggestion(
name: 'fail',
description:
'Log all warnings and fail the build if there are any warnings',
),
FigSuggestion(
name: 'summary',
description:
'Suppress all warnings and log a summary at the end of the build',
),
FigSuggestion(
name: 'none',
description:
'Suppress all warnings, including the summary at the end of the build',
),
],
);