submitOptions top-level property
Implementation
final List<Option> submitOptions = [
Option(
name: '--always',
description: 'Always push updates, even if the branch has not changed. Can be helpful for fixing an inconsistent Graphite stack view on Web/GitHub resulting from downtime/a bug'
),
Option(
name: '--branch',
description: 'Which branch to run this command from. Defaults to the current branch',
args: [
Arg(
name: 'branch',
description: 'Name of branch'
)
]
),
Option(
name: ['--confirm', '-c'],
description: 'Reports the PRs that would be submitted and asks for confirmation before pushing branches and opening/updating PRs. If either of --no-interactive or --dry-run is passed, this flag is ignored'
),
Option(
name: ['--draft', '-d'],
description: 'If set, marks PR as draft. If --no-interactive is true, new PRs will be created in draft mode'
),
Option(
name: '--dry-run',
description: 'Reports the PRs that would be submitted and terminates. No branches are pushed and no PRs are opened or updated'
),
Option(
name: ['--edit', '-e'],
description: 'Input metadata for all PRs interactively. If neither --edit nor --no-edit is passed, only prompts for new PRs'
),
Option(
name: ['--force', '-f'],
description: 'Force push: overwrites the remote branch with your local branch. Otherwise defaults to --force-with-lease'
),
Option(
name: ['--merge-when-ready', '-m'],
description: 'If set, marks all PRs being submitted as merge when ready, which will let them automatically merge as soon as all merge requirements are met'
),
Option(
name: ['--no-edit', '-n'],
description: 'Don\'t edit PR fields inline. Takes precedence over --edit'
),
Option(
name: ['--publish', '-p'],
description: 'If set, publishes PR. If --no-interactive is true, new PRs will be created in draft mode'
),
Option(
name: '--rerequest-review',
description: 'Rerequest review from current reviewers'
),
Option(
name: '--restack',
description: 'Restack branches before submitting. If there are conflicts, output the branch names that could not be restacked'
),
Option(
name: ['--reviewers', '-r'],
description: 'If set without an argument, prompt to manually set reviewers. Alternatively, accepts a comma separated string of reviewers',
args: [
Arg(
name: 'reviewers',
description: 'Comma separated string of reviewers',
isOptional: true
)
]
),
Option(
name: ['--stack', '-s'],
description: 'Submit descendants of the current branch in addition to its ancestors'
),
Option(
name: ['--update-only', '-u'],
description: 'Only update the PRs that have been already been submitted'
)
];