androidGeneralOptions top-level property
Implementation
final List<FigOption> androidGeneralOptions = [
FigOption(
name: ['--aab'],
description:
'Specifies that the command will produce and deploy an Android App Bundle',
),
FigOption(
name: ['--env.snapshot'],
description:
'Creates a V8 Snapshot decreasing the app start time (only for release builds for Android)',
dependsOn: ['--release'],
),
FigOption(
name: ['--env.compileSnapshot'],
description:
'Compiles the static assets produced by --env.snapshot into .so files allowing the native build to split them per architecture. This will reduce the app size when using the --aab option',
dependsOn: ['--env.snapshot', '--aab'],
),
FigOption(
name: ['--env.appComponents'],
description: 'Allows passing additional App Components for android',
),
];