androidKeyOptions top-level property
Implementation
final List<FigOption> androidKeyOptions = [
FigOption(
name: ['--key-store-path'],
description:
'Specifies the file path to the keystore file (P12) which you want to use to code sign your APK',
args: [FigArg(name: 'path', template: 'filepaths')],
dependsOn: ['--release'],
),
FigOption(
name: ['--key-store-password'],
description:
'Provides the password for the keystore file specified with --key-store-path',
args: [FigArg(name: 'password')],
dependsOn: ['--release'],
),
FigOption(
name: ['--key-store-alias'],
description:
'Provides the alias for the keystore file specified with --key-store-path',
args: [FigArg(name: 'alias')],
dependsOn: ['--release'],
),
FigOption(
name: ['--key-store-alias-password'],
description:
'Provides the password for the alias specified with --key-store-alias-password',
args: [FigArg(name: 'alias password')],
dependsOn: ['--release'],
),
];