appStoreCommand top-level property
Implementation
final FigSubcommand appStoreCommand = FigSubcommand(
name: ['appstore'],
description:
'Lists all application records in iTunes Connect. The list contains name, version and bundle ID for each application record',
subcommands: [
FigSubcommand(
name: ['upload'],
description:
'Uploads project to iTunes Connect. The command either issues a production build and uploads it to iTunes Connect, or uses an already built package to upload',
args: [
FigArg(
name: 'appleId',
description: 'Apple id for logging in iTunes Connect'),
FigArg(
name: 'password',
description: 'Password for logging in iTunes Connect'),
FigArg(
name: 'mobile provisioning profile identifier',
description:
'The identifier of the mobile provision(e.g. d5d40f61-b303-4fc8-aea3-fbb229a8171c) which will be used for building. This can easily be acquired through the iPhone Configuration Utility'),
FigArg(
name: 'code sign identity',
description:
'The code sign identity which will be used for building. You can set it to something generic like \'iPhone Distribution\' to let the build automatically detect a code sign identity'),
],
options: [
FigOption(
name: ['--ipa'],
description:
'Use the provided .ipa file instead of building the project',
args: [FigArg(name: 'ipa file path', template: 'filepaths')],
),
FigOption(
name: ['--appleApplicationSpecificPassword'],
description:
'Specifies the password for accessing the information you store in iTunes Transporter application',
args: [FigArg(name: 'password')],
),
FigOption(
name: ['--appleSessionBase64'],
description:
'The session that will be used instead of triggering a new login each time NativeScript CLI communicates with Apple\'s APIs',
args: [FigArg(name: 'base64')],
),
],
),
],
args: [
FigArg(
name: 'appleId',
description:
'Credentials for logging in iTunes Connect. If you do not provide them when running the command, the NativeScript CLI will prompt you to provide them'),
FigArg(
name: 'password',
description: 'Password for logging in iTunes Connect'),
],
options: [
FigOption(
name: ['--team-id'],
description:
'Specifies the team id for which Xcode will try to find distribution certificate and provisioning profile when exporting for AppStore submission',
args: [FigArg(name: 'team id')],
),
helpOption('appstore'),
],
);