buildBothOptions top-level property
Implementation
final List<FigOption> buildBothOptions = [
...platformEnvOptions,
releaseOption,
FigOption(
name: ['--copy-to'],
description:
'Specifies the file path where the built .ipa|.apk will be copied. If it points to a non-existent directory path, it will be created. If the specified value is existing directory, the original file name will be used',
args: [FigArg(name: 'path', template: 'folders')],
),
FigOption(
name: ['--path'],
description:
'Specifies the directory where you want to create the project, if different from the current directory',
args: [FigArg(name: 'directory', template: 'folders')],
),
forceOption,
cleanOption,
deviceOption,
];