debugIosOptions top-level property
Implementation
final List<FigOption> debugIosOptions = [
FigOption(
name: ['--no-client'],
description:
'The NativeScript CLI attaches the debug tools but does not launch the developer tools in Safari. Could be used on already started Safari Web Inspector',
),
FigOption(
name: ['--inspector'],
description:
'The developer tools in the Safari Web Inspector are used for debugging the application',
),
];