deployCommand top-level property
Implementation
final FigSubcommand deployCommand = FigSubcommand(
name: ['deploy'],
description:
'Prepares, builds and deploys the project to a connected device or native emulator. You must specify the target platform on which you want to deploy. It will deploy the app on all connected devices targeting the selected platform',
subcommands: [
FigSubcommand(
name: ['android'],
options: [...deployBothOptions, ...deployAndroidOptions],
priority: 90,
),
FigSubcommand(
name: ['ios'],
options: [...deployBothOptions, ...deployIosOptions],
priority: 90,
),
],
options: [helpOption('deploy')],
);