deviceCommand top-level property
Implementation
final FigSubcommand deviceCommand = FigSubcommand(
name: ['device', 'devices'],
description:
'Lists all recognized connected Android or iOS devices with serial number and index, grouped by platform',
subcommands: [
FigSubcommand(
name: ['android'],
description:
'Lists all recognized connected Android physical and running Android virtual devices',
options: [
timeoutOption,
FigOption(
name: ['--available-devices'],
description: 'Lists all available Android devices'),
jsonOption,
],
),
FigSubcommand(
name: ['ios'],
description:
'Lists all recognized connected iOS devices with serial number and index',
options: [
timeoutOption,
FigOption(
name: ['--available-devices'],
description: 'Lists all available iOS devices'),
jsonOption,
],
),
FigSubcommand(
name: ['log'],
description:
'Opens the device log stream for a selected connected device',
options: [deviceOption],
),
FigSubcommand(
name: ['list-applications'],
description:
'Lists the installed applications on all connected Android or iOS devices',
options: [deviceOption],
),
FigSubcommand(
name: ['run'],
description:
'Runs the selected application on a connected Android or iOS device',
args: [
FigArg(
name: 'application id', description: 'The application identifier'),
],
options: [deviceOption],
),
],
options: [
FigOption(
name: ['--available-devices'],
description: 'Lists all available devices'),
jsonOption,
helpOption('device'),
],
);