doctorCommand top-level property
Implementation
final FigSubcommand doctorCommand = FigSubcommand(
name: ['doctor'],
description:
'Checks your system for configuration problems which might prevent the NativeScript CLI from working properly for the specified platform, if configured',
subcommands: [
FigSubcommand(
name: ['android'],
description: 'Check your system configuration for android',
),
FigSubcommand(
name: ['ios'],
description: 'Check your system configuration for ios',
),
],
options: [helpOption('doctor')],
);