installCommand top-level property
Implementation
final FigSubcommand installCommand = FigSubcommand(
name: ['install'],
description:
'Installs all dependencies described in a valid package.json or installs a selected NativeScript development module as a dev dependency',
subcommands: [
FigSubcommand(
name: ['typescript'], description: 'Enable TypeScript support'),
],
args: [
FigArg(
name: 'module',
description:
'Specifies a NativeScript development module by path to a local directory containing a valid npm module or by name in the npm registry')
],
options: [
FigOption(
name: ['--path'],
description:
'Specifies the directory which contains the package.json file, if different from the current directory',
args: [FigArg(name: 'directory', template: 'folders')],
),
helpOption('install'),
],
);