pluginCommand top-level property
Implementation
final FigSubcommand pluginCommand = FigSubcommand(
name: ['plugin'],
description: 'Manage the plugins for your project',
subcommands: [
FigSubcommand(
name: ['add'],
description: 'Installs the specified plugin and its dependencies',
args: [
FigArg(name: 'plugin', description: 'A valid Nativescript plugin')
],
),
FigSubcommand(
name: ['remove'],
description: 'Uninstalls the specified plugin and its dependencies',
args: [
FigArg(name: 'plugin', description: 'A valid Nativescript plugin')
],
),
FigSubcommand(
name: ['update'],
description:
'Uninstalls and installs the specified plugin(s) and its dependencies',
args: [
FigArg(name: 'plugin(s)', description: 'A valid Nativescript plugin')
],
),
FigSubcommand(
name: ['build'],
description: 'Builds the Android parts of a NativeScript plugin',
),
FigSubcommand(
name: ['create'],
description: 'Creates a project for building a new NativeScript plugin',
args: [
FigArg(
name: 'plugin repository name',
description: 'A valid Nativescript plugin repository')
],
options: [
FigOption(
name: ['--path'],
description:
'Specifies the directory where you want to create the project, if different from the current directory',
args: [
FigArg(
name: 'directory',
description:
'Specifies the directory where you want to create the project, if different from the current directory',
template: 'folders')
],
),
FigOption(
name: ['--username'],
description:
'Specifies the GitHub username, which will be used to build the URLs in the plugin\'s package.json file',
args: [FigArg(name: 'username', description: 'GitHub username')],
),
FigOption(
name: ['--pluginName'],
description:
'Used to set the default file and class names in the plugin source',
args: [FigArg(name: 'name')],
),
FigOption(
name: ['--includeTypeScriptDemo'],
description: 'Specifies if a TypeScript demo should be created',
),
FigOption(
name: ['--includeTypeScriptDemo=n'],
description: 'Specifies if TypeScript demo should NOT be created',
),
FigOption(
name: ['--includeAngularDemo'],
description: 'Specifies if an Angular demo should be created',
),
FigOption(
name: ['--includeAngularDemo=n'],
description: 'Specifies if Angular demo should NOT be created',
),
FigOption(
name: ['--template'],
description:
'Specifies the custom seed archive, which you want to use to create your plugin',
args: [
FigArg(
name: 'template',
description: 'Specifies the template for the plugin')
],
),
],
),
],
options: [helpOption('plugin')],
);