resourcesCommand top-level property
Implementation
final FigSubcommand resourcesCommand = FigSubcommand(
name: ['resources'],
description: 'Manage the plugins for your project',
subcommands: [
FigSubcommand(
name: ['update'],
description:
'Updates the App_Resources\'s internal folder structure to conform to that of an Android Studio project',
),
FigSubcommand(
name: ['generate'],
subcommands: [
FigSubcommand(
name: ['splashes'],
args: [
FigArg(
name: 'image path',
description:
'Path to an image that will be used to generate all splashscreens',
template: 'filepaths')
],
options: [
FigOption(
name: ['--background'],
description: 'Sets the background color of the splashscreen',
args: [FigArg(name: 'color', defaultValue: 'white')],
),
],
),
FigSubcommand(
name: ['icons'],
args: [
FigArg(
name: 'image path',
description:
'Path to an image that will be used to generate all splashscreens',
template: 'filepaths')
],
),
],
),
],
options: [helpOption('plugin')],
);