testCommand top-level property
Implementation
final FigSubcommand testCommand = FigSubcommand(
name: ['test'],
description: 'Runs unit tests on the selected mobile platform',
subcommands: [
FigSubcommand(
name: ['init'],
description: 'Configure your project for unit testing',
options: [
FigOption(
name: ['--framework'],
description: 'Sets the unit testing framework to install',
args: [
FigArg(
name: 'framework',
suggestions: [
FigSuggestion(name: 'mocha'),
FigSuggestion(name: 'jasmine'),
FigSuggestion(name: 'qunit')
],
),
],
),
],
),
FigSubcommand(
name: ['android'],
description:
'Run unit tests on all connected android devices or native emulators',
options: [...testBothOptions, ...testAndroidOptions],
priority: 90,
),
FigSubcommand(
name: ['ios'],
description:
'Run unit tests on all connected ios devices or native emulators',
options: [...testBothOptions, ...testIosOptions],
priority: 90,
),
],
options: [helpOption('test')],
);