phpunitWatcherSpec top-level property
Implementation
final FigSpec phpunitWatcherSpec = FigSpec(
name: 'phpunit-watcher',
description: 'Automatically rerun PHPUnit tests when source code changes',
subcommands: [
FigSubcommand(
name: ['watch'],
description:
'This will run the tests and rerun them whenever a file in the app, src or tests directory is modified',
options: [
FigOption(
name: ['--filter'],
description: 'Watch a specific test',
args: [
FigArg(
generators: [tests],
name: 'filter',
),
],
),
],
),
],
);