INSTALL_BASE_OPTIONS top-level property
Implementation
final List<Option> INSTALL_BASE_OPTIONS = [
Option(
name: '--offline',
description:
'If true, pnpm will use only packages already available in the store. If a package won\'t be found locally, the installation will fail'),
Option(
name: '--prefer-offline',
description:
'If true, staleness checks for cached data will be bypassed, but missing data will be requested from the server. To force full offline mode, use --offline'),
Option(
name: '--ignore-scripts',
description:
'Do not execute any scripts defined in the project package.json and its dependencies'),
Option(
name: '--reporter',
description:
'Allows you to choose the reporter that will log debug info to the terminal about the installation progress',
args: [
Arg(name: 'Reporter Type', suggestions: [
FigSuggestion(name: 'silent'),
FigSuggestion(name: 'default'),
FigSuggestion(name: 'append-only'),
FigSuggestion(name: 'ndjson')
])
])
];