INSTALL_PACKAGE_OPTIONS top-level property
Implementation
final List<Option> INSTALL_PACKAGE_OPTIONS = [
Option(
name: ['-P', '--save-prod'],
description: 'Install the specified packages as regular dependencies'),
Option(
name: ['-D', '--save-dev'],
description: 'Install the specified packages as devDependencies'),
Option(
name: ['-O', '--save-optional'],
description: 'Install the specified packages as optionalDependencies'),
Option(name: '--no-save', description: 'Prevents saving to \'dependencies\''),
Option(
name: ['-E', '--save-exact'],
description:
'Saved dependencies will be configured with an exact version rather than using pnpm\'s default semver range operator'),
Option(
name: '--save-peer',
description:
'Using --save-peer will add one or more packages to peerDependencies and install them as dev dependencies'),
Option(
name: ['--ignore-workspace-root-check', '-W#'],
// TS_UNCONVERTED_START (description)
// 'Adding a new dependency to the root workspace package fails, unless the --ignore-workspace-root-check or -W flag is used.
// For instance, pnpm add debug -W'
// TS_UNCONVERTED_END
description: null),
Option(name: ['--global', '-g'], description: 'Install a package globally'),
Option(
name: '--workspace',
description:
'Only adds the new dependency if it is found in the workspace'),
FILTER_OPTION
];