sharedOptions top-level property
Implementation
final List<Option> sharedOptions = [
Option(
name: ['-s', '--show-headers'],
description: 'Shows response HTTP headers'
),
Option(
name: ['-c', '--confirm'],
description: 'Skips the warning prompt and automatically confirms the command being entered',
isDangerous: true
),
Option(
name: '--dark-style',
description: 'Uses a darker color scheme'
),
Option(
name: ['-d', '--data'],
description: 'Additional data to send with an API request',
args: [
Arg(
name: 'value'
)
]
),
Option(
name: ['-e', '--expand'],
description: 'Response attributes to expand inline',
args: [
Arg(
name: 'value'
)
]
),
Option(
name: ['-i', '--idempotency'],
description: 'Sets an idempotency key for the request, preventing the same request from replaying within 24 hours',
args: [
Arg(
name: 'key'
)
]
),
Option(
name: '--live',
description: 'Makes a live request'
),
Option(
name: '--stripe-account',
description: 'Specify the Stripe account to use for this request',
args: [
Arg(
name: 'account id'
)
]
),
Option(
name: ['-v', '--stripe-version'],
description: 'Specify the Stripe API version to use for this request',
args: [
Arg(
name: 'version'
)
]
)
];