addOptions top-level property
Implementation
final List<Option> addOptions = [
Option(
name: ['-r', '--requirements'],
description:
'Add all packages listed in the given `requirements.txt` files',
args: [Arg(name: 'REQUIREMENTS')]),
Option(
name: '--dev',
description: 'Add the requirements to the development dependency group'),
Option(
name: '--optional',
description:
'Add the requirements to the package\'s optional dependencies for the specified extra',
args: [Arg(name: 'OPTIONAL')]),
Option(
name: '--group',
description: 'Add the requirements to the specified dependency group',
args: [Arg(name: 'GROUP')]),
Option(name: '--editable', description: 'Add the requirements as editable'),
Option(
name: '--raw-sources',
description:
'Add source requirements to `project.dependencies`, rather than `tool.uv.sources`'),
Option(
name: '--rev',
description: 'Commit to use when adding a dependency from Git',
args: [Arg(name: 'REV')]),
Option(
name: '--tag',
description: 'Tag to use when adding a dependency from Git',
args: [Arg(name: 'TAG')]),
Option(
name: '--branch',
description: 'Branch to use when adding a dependency from Git',
args: [Arg(name: 'BRANCH')]),
Option(
name: '--extra',
description: 'Extras to enable for the dependency',
args: [Arg(name: 'EXTRA')]),
Option(
name: '--no-sync',
description: 'Avoid syncing the virtual environment',
args: [Arg(name: 'UV_NO_SYNC')]),
Option(
name: '--locked',
description: 'Assert that the `uv.lock` will remain unchanged',
args: [Arg(name: 'UV_LOCKED')]),
Option(
name: '--frozen',
description: 'Add dependencies without re-locking the project',
args: [Arg(name: 'UV_FROZEN')]),
Option(
name: '--package',
description: 'Add the dependency to a specific package in the workspace',
args: [Arg(name: 'PACKAGE')]),
Option(
name: '--script',
description:
'Add the dependency to the specified Python script, rather than to a project',
args: [Arg(name: 'SCRIPT')])
];