cacheOptions top-level property
Implementation
final List<Option> cacheOptions = [
Option(
name: '--no-cache',
description:
'Avoid reading from or writing to the cache, instead using a temporary directory for the duration of the operation'),
Option(
name: '--cache-dir',
description: 'Path to the cache directory',
args: [Arg(name: 'CACHE_DIR')]),
Option(name: '--refresh', description: 'Refresh all cached data'),
Option(
name: '--refresh-package',
description: 'Refresh cached data for a specific package',
args: [Arg(name: 'REFRESH_PACKAGE')])
];