pipSubcommands top-level property
Implementation
final List<FigSubcommand> pipSubcommands = [
Subcommand(
name: 'compile',
description:
'Compile a `requirements.in` file to a `requirements.txt` file'),
Subcommand(
name: 'sync',
description: 'Sync an environment with a `requirements.txt` file',
args: [
Arg(
name: 'REQUIREMENTS',
description: 'The path to the requirements file')
]),
Subcommand(
name: 'install',
description: 'Install packages into an environment',
args: [
Arg(
name: 'PACKAGES',
description: 'Packages to install',
isVariadic: true)
]),
Subcommand(
name: 'uninstall',
description: 'Uninstall packages from an environment',
args: [
Arg(
name: 'PACKAGES',
description: 'Packages to uninstall',
isVariadic: true)
]),
Subcommand(
name: 'freeze',
description:
'List, in requirements format, packages installed in an environment'),
Subcommand(
name: 'list',
description:
'List, in tabular format, packages installed in an environment'),
Subcommand(
name: 'show',
description: 'Show information about one or more installed packages',
args: [
Arg(name: 'PACKAGES', description: 'Packages to show', isVariadic: true)
]),
Subcommand(
name: 'tree',
description: 'Display the dependency tree for an environment'),
Subcommand(
name: 'check',
description: 'Verify installed packages have compatible dependencies')
];