pythonSubcommands top-level property
Implementation
final List<FigSubcommand> pythonSubcommands = [
Subcommand(
name: 'list',
description: 'List the available Python installations',
options: [
Option(
name: '--all-versions',
description:
'List all Python versions, including old patch versions'),
Option(
name: '--all-platforms',
description: 'List Python downloads for all platforms'),
Option(
name: '--only-installed',
description:
'Only show installed Python versions, exclude available downloads')
]),
Subcommand(
name: 'install',
description: 'Download and install Python versions',
args: [
Arg(name: 'VERSION', description: 'The Python version to install')
],
options: [
Option(
name: '--mirror',
description:
'Set the URL to use as the source for downloading Python installations',
args: [Arg(name: 'MIRROR')]),
Option(
name: '--pypy-mirror',
description:
'Set the URL to use as the source for downloading PyPy installations',
args: [Arg(name: 'PYPY_MIRROR')]),
Option(
name: '--reinstall',
description:
'Reinstall the requested Python version, if it\'s already installed'),
Option(
name: '--force',
description:
'Replace existing Python executables during installation'),
Option(
name: '--default', description: 'Use as the default Python version')
]),
Subcommand(
name: 'find',
description: 'Search for a Python installation',
args: [
Arg(name: 'REQUEST', description: 'The Python request')
],
options: [
Option(
name: '--no-project',
description: 'Avoid discovering the project or workspace'),
Option(
name: '--system',
description:
'Only find system Python interpreters [env: UV_SYSTEM_PYTHON=]')
]),
Subcommand(
name: 'pin',
description: 'Pin to a specific Python version',
args: [
Arg(name: 'REQUEST', description: 'The Python request')
],
options: [
Option(
name: '--resolved',
description:
'Write the resolved Python interpreter path instead of the request'),
Option(
name: '--no-project',
description: 'Avoid discovering the project or workspace')
]),
Subcommand(
name: 'dir',
description: 'Show the uv Python installation directory',
options: [
Option(
name: '--bin',
description:
'Show the directory into which `uv python` will install Python executables')
]),
Subcommand(
name: 'uninstall',
description: 'Uninstall Python versions',
args: [
Arg(name: 'VERSION', description: 'The Python version to uninstall')
],
options: [
Option(name: '--all', description: 'Uninstall all Python versions')
])
];