removeOptions top-level property
Implementation
final List<Option> removeOptions = [
Option(
name: '--dev',
description: 'Remove the packages from the development dependency group'),
Option(
name: '--optional',
description:
'Remove the packages from the project\'s optional dependencies for the specified extra',
args: [Arg(name: 'OPTIONAL')]),
Option(
name: '--group',
description: 'Remove the packages from the specified dependency group',
args: [Arg(name: 'GROUP')]),
Option(
name: '--no-sync',
description:
'Avoid syncing the virtual environment after re-locking the project',
args: [Arg(name: 'UV_NO_SYNC')]),
Option(
name: '--locked',
description: 'Assert that the `uv.lock` will remain unchanged',
args: [Arg(name: 'UV_LOCKED')]),
Option(
name: '--frozen',
description: 'Remove dependencies without re-locking the project',
args: [Arg(name: 'UV_FROZEN')]),
Option(
name: '--package',
description:
'Remove the dependencies from a specific package in the workspace',
args: [Arg(name: 'PACKAGE')]),
Option(
name: '--script',
description:
'Remove the dependency from the specified Python script, rather than from a project',
args: [Arg(name: 'SCRIPT')])
];