runOptions top-level property
Implementation
final List<Option> runOptions = [
Option(
name: '--extra',
description:
'Include optional dependencies from the specified extra name',
args: [Arg(name: 'EXTRA')]),
Option(
name: '--all-extras', description: 'Include all optional dependencies'),
Option(
name: '--no-extra',
description:
'Exclude the specified optional dependencies, if `--all-extras` is supplied',
args: [Arg(name: 'NO_EXTRA')]),
Option(
name: '--no-dev', description: 'Omit the development dependency group'),
Option(
name: '--group',
description: 'Include dependencies from the specified dependency group',
args: [Arg(name: 'GROUP')]),
Option(
name: '--no-group',
description: 'Exclude dependencies from the specified dependency group',
args: [Arg(name: 'NO_GROUP')]),
Option(
name: '--only-group',
description:
'Only include dependencies from the specified dependency group',
args: [Arg(name: 'ONLY_GROUP')]),
Option(
name: '--all-groups',
description: 'Include dependencies from all dependency groups'),
Option(name: ['-m', '--module'], description: 'Run a Python module'),
Option(
name: '--only-dev',
description: 'Only include the development dependency group'),
Option(
name: '--no-editable',
description:
'Install any editable dependencies, including the project and any workspace members, as non-editable'),
Option(
name: '--env-file',
description: 'Load environment variables from a `.env` file',
args: [Arg(name: 'ENV_FILE')]),
Option(
name: '--no-env-file',
description: 'Avoid reading environment variables from a `.env` file'),
Option(
name: '--with',
description: 'Run with the given packages installed',
args: [Arg(name: 'WITH')]),
Option(
name: '--with-editable',
description: 'Run with the given packages installed as editables',
args: [Arg(name: 'WITH_EDITABLE')]),
Option(
name: '--with-requirements',
description:
'Run with all packages listed in the given `requirements.txt` files',
args: [Arg(name: 'WITH_REQUIREMENTS')]),
Option(
name: '--isolated',
description: 'Run the command in an isolated virtual environment'),
Option(
name: '--no-sync', description: 'Avoid syncing the virtual environment'),
Option(
name: '--locked',
description: 'Assert that the `uv.lock` will remain unchanged'),
Option(
name: '--frozen', description: 'Run without updating the `uv.lock` file'),
Option(
name: ['-s', '--script'],
description: 'Run the given path as a Python script'),
Option(
name: '--all-packages',
description: 'Run the command with all workspace members installed'),
Option(
name: '--package',
description: 'Run the command in a specific package in the workspace',
args: [Arg(name: 'PACKAGE')]),
Option(
name: '--no-project',
description: 'Avoid discovering the project or workspace')
];