syncOptions top-level property
Implementation
final List<Option> syncOptions = [
Option(
name: '--extra',
description:
'Include optional dependencies from the specified extra name',
args: [Arg(name: 'EXTRA')]),
Option(
name: '--all-extras', description: 'Include all optional dependencies'),
Option(
name: '--no-extra',
description:
'Exclude the specified optional dependencies, if `--all-extras` is supplied',
args: [Arg(name: 'NO_EXTRA')]),
Option(
name: '--no-dev', description: 'Omit the development dependency group'),
Option(
name: '--only-dev',
description: 'Only include the development dependency group'),
Option(
name: '--group',
description: 'Include dependencies from the specified dependency group',
args: [Arg(name: 'GROUP')]),
Option(
name: '--no-group',
description: 'Exclude dependencies from the specified dependency group',
args: [Arg(name: 'NO_GROUP')]),
Option(
name: '--only-group',
description:
'Only include dependencies from the specified dependency group',
args: [Arg(name: 'ONLY_GROUP')]),
Option(
name: '--all-groups',
description: 'Include dependencies from all dependency groups'),
Option(
name: '--no-editable',
description:
'Install any editable dependencies, including the project and any workspace members, as non-editable'),
Option(
name: '--inexact',
description:
'Do not remove extraneous packages present in the environment'),
Option(
name: '--no-install-project',
description: 'Do not install the current project'),
Option(
name: '--no-install-workspace',
description:
'Do not install any workspace members, including the root project'),
Option(
name: '--no-install-package',
description: 'Do not install the given package(s)',
args: [Arg(name: 'NO_INSTALL_PACKAGE')]),
Option(
name: '--locked',
description: 'Assert that the `uv.lock` will remain unchanged',
args: [Arg(name: 'UV_LOCKED')]),
Option(
name: '--frozen',
description: 'Sync without updating the `uv.lock` file',
args: [Arg(name: 'UV_FROZEN')]),
Option(
name: '--all-packages',
description: 'Sync all packages in the workspace'),
Option(
name: '--package',
description: 'Sync for a specific package in the workspace',
args: [Arg(name: 'PACKAGE')])
];