vaultAuditEnableOptions top-level property
Implementation
final List<Option> vaultAuditEnableOptions = [
Option(
name: '-description',
description: 'Human-friendly description for the purpose of this audit device',
args: [
Arg(
name: 'string'
)
],
priority: 38
),
Option(
name: '-local',
description: 'Mark the audit device as a local-only device. Local devices are not replicated or removed by replication. The default is false',
args: [
Arg(
name: 'string',
suggestions: [
FigSuggestion(name: 'false'),
FigSuggestion(name: 'true')
],
defaultValue: 'false'
)
],
priority: 38
),
Option(
name: '-path',
description: 'Place where the audit device will be accessible. This must be unique across all audit devices. This defaults to the \'type\' of the audit device',
args: [
Arg(
name: 'string'
)
],
priority: 38
)
];