vaultDebugOptions top-level property
Implementation
final List<Option> vaultDebugOptions = [
Option(
name: '-compress',
description: 'Toggles whether to compress output package The default is true',
args: [
Arg(
name: 'string',
suggestions: [
FigSuggestion(name: 'true'),
FigSuggestion(name: 'true')
],
defaultValue: 'true'
)
],
priority: 38
),
Option(
name: '-duration',
description: 'Duration to run the command. The default is 2m0s',
args: [
Arg(
name: 'string',
suggestions: [
FigSuggestion(name: '2m0s')
],
defaultValue: '2m0s'
)
],
priority: 38
),
Option(
name: '-interval',
description: 'The polling interval at which to collect profiling data and server state. The default is 30s',
args: [
Arg(
name: 'string',
suggestions: [
FigSuggestion(name: '30s')
],
defaultValue: '30s'
)
],
priority: 38
),
Option(
name: '-metrics-interval',
description: 'The polling interval at which to collect metrics data. The default is 10s',
args: [
Arg(
name: 'string',
suggestions: [
FigSuggestion(name: '10s')
],
defaultValue: '10s'
)
],
priority: 38
),
Option(
name: '-output',
description: 'Specifies the output path for the debug package',
args: [
Arg(
name: 'string'
)
],
priority: 38
),
Option(
name: '-target',
description: 'Target to capture, defaulting to all if none specified. This can be specified multiple times to capture multiple targets',
args: [
Arg(
name: 'string',
suggestions: [
FigSuggestion(name: 'config'),
FigSuggestion(name: 'host'),
FigSuggestion(name: 'metrics'),
FigSuggestion(name: 'pprof'),
FigSuggestion(name: 'replication-status'),
FigSuggestion(name: 'server-stauts'),
FigSuggestion(name: 'log')
]
)
],
priority: 38
)
];