vaultKvMetadataPatchAndPutOptions top-level property
List<Option>
vaultKvMetadataPatchAndPutOptions
final
Implementation
final List<Option> vaultKvMetadataPatchAndPutOptions = [
Option(
name: '-cas-required',
description: 'If true the key will require the cas parameter to be set on all write requests. If false, the backend’s configuration will be used',
args: [
Arg(
name: 'string'
)
],
priority: 38
),
Option(
name: '-custom-metadata',
description: 'Specifies arbitrary version-agnostic key=value metadata meant to describe a secret. This can be specified multiple times to add multiple pieces of metadata',
args: [
Arg(
name: 'key=value'
)
],
priority: 38
),
Option(
name: '-delete-version-after',
description: 'Specifies the length of time before a version is deleted. If not set, the backend\'s configured delete-version-after is used. Cannot be greater than the backend\'s delete-version-after. The delete-version-after is specified as a numeric string with a suffix like \'30s\' or \'3h25m19s\'. The default is -1ns',
args: [
Arg(
name: 'duration',
suggestions: [
FigSuggestion(name: '30s'),
FigSuggestion(name: '3h25m19s')
],
defaultValue: '-1ns'
)
],
priority: 38
),
Option(
name: '-max-versions',
description: 'The number of versions to keep. If not set, the backend’s configured max version is used. The default is -1',
args: [
Arg(
name: 'duration',
suggestions: [
FigSuggestion(name: '-1')
],
defaultValue: '-1'
)
],
priority: 38
)
];