vaultOperatorDiagnoseOptions top-level property
Implementation
final List<Option> vaultOperatorDiagnoseOptions = [
Option(
name: '-config',
description: 'Path to a Vault configuration file or directory of configuration files. This flag can be specified multiple times to load multiple configurations. If the path is a directory, all files which end in .hcl or .json are loaded',
args: [
Arg(
name: 'string',
template: 'filepaths'
)
],
priority: 38
),
Option(
name: '-debug',
description: 'Dump all information collected by Diagnose',
priority: 38
),
Option(
name: '-format',
description: 'The output format',
args: [
Arg(
name: 'format',
suggestions: [
FigSuggestion(name: 'table'),
FigSuggestion(name: 'json'),
FigSuggestion(name: 'yaml'),
FigSuggestion(name: 'pretty')
],
defaultValue: 'table'
)
],
priority: 38
),
Option(
name: '-skip',
description: 'Skip the health checks named as arguments',
args: [
Arg(
name: 'string',
suggestions: [
FigSuggestion(name: 'listen'),
FigSuggestion(name: 'storage'),
FigSuggestion(name: 'autounseal')
]
)
],
priority: 38
)
];