vaultOperatorInitOptions top-level property
Implementation
final List<Option> vaultOperatorInitOptions = [
Option(
name: ['-key-shares', '-n'],
description: 'Number of key shares to split the generated root key into. This is the number of \'unseal keys\' to generate. This is aliased as \'-n\'. The default is 5',
args: [
Arg(
name: 'int',
suggestions: [
FigSuggestion(name: '5')
],
defaultValue: '5'
)
]
),
Option(
name: ['-key-threshold', '-t'],
description: 'Number of key shares required to reconstruct the root key. This must be less than or equal to -key-shares. This is aliased as \'-t\'. The default is 3',
args: [
Arg(
name: 'int',
suggestions: [
FigSuggestion(name: '5')
],
defaultValue: '5'
)
]
),
Option(
name: '-pgp-keys',
description: 'Comma-separated list of paths to files on disk containing public PGP keys OR a comma-separated list of Keybase usernames using the format \'keybase:<username>\'. When supplied, the generated unseal keys will be encrypted and base64-encoded in the order specified in this list. The number of entries must match -key-shares, unless -stored-shares are used',
args: [
Arg(
name: 'pgp_key',
suggestions: [
FigSuggestion(name: 'keybase:user1'),
FigSuggestion(name: '/path/to/pgp/key1,/path/to/pgp/key2')
],
template: 'filepaths'
)
]
),
Option(
name: '-root-token-pgp-key',
description: 'Path to a file on disk containing a binary or base64-encoded public PGP key. This can also be specified as a Keybase username using the format \'keybase:<username>\'. When supplied, the generated root token will be encrypted and base64-encoded with the given public key',
args: [
Arg(
name: 'pgp_key',
suggestions: [
FigSuggestion(name: 'keybase:user1'),
FigSuggestion(name: '/path/to/pgp/key')
],
template: 'filepaths'
)
]
),
Option(
name: '-status',
description: 'Print the current initialization status. An exit code of 0 means the Vault is already initialized. An exit code of 1 means an error occurred. An exit code of 2 means the Vault is not initialized. The default is false'
),
Option(
name: '-stored-shares',
description: 'DEPRECATED: This flag does nothing. It will be removed in Vault 1.3. The default is -1',
args: [
Arg(
name: 'int',
suggestions: [
FigSuggestion(name: '-1')
],
defaultValue: '-1'
)
]
)
];