vaultTokenRevokeOptions top-level property
Implementation
final List<Option> vaultTokenRevokeOptions = [
Option(
name: '-accessor',
description: 'Treat the argument as an accessor instead of a token. When this option is selected, the output will NOT include the token. The default is false'
),
Option(
name: '-mode',
description: 'Type of revocation to perform. If unspecified, Vault will revoke the token and all of the token\'s children. If \'orphan\', Vault will revoke only the token, leaving the children as orphans. If \'path\', tokens created from the given authentication path prefix are deleted along with their children',
args: [
Arg(
name: 'duration',
suggestions: [
FigSuggestion(name: 'orphan'),
FigSuggestion(name: 'path')
]
)
]
),
Option(
name: '-self',
description: 'Perform the revocation on the currently authenticated token. The default is false'
)
];