wcSpec top-level property
Completion spec for wc CLI
Implementation
final FigSpec wcSpec = FigSpec(
name: 'wc',
description: 'World, line, character, and byte count',
options: [
Option(
name: '-c',
description: 'Output the number of bytes to the standard input'
),
Option(
name: '-l',
description: 'Output the number of lines to the standard input'
),
Option(
name: '-m',
description: 'Output the number of characters to the standard input'
),
Option(
name: '-w',
description: 'Output the number of words to the standard input'
)
],
args: [
Arg(
name: 'file',
description: 'File to count in',
template: 'filepaths',
isOptional: true,
isVariadic: true
)
]
);